_positive = set(
    [
        "abba",
        "umiejętność",
        "NO TRANSLATION",
        "absolutny",
        "rozgrzeszenie",
        "zaabsorbowany",
        "obfity",
        "akademicki",
        "akademia",
        "do przyjęcia",
        "przyjęcie",
        "dostępny",
        "uznanie",
        "nocleg",
        "akompaniament",
        "ukończyć",
        "znakomity",
        "osiągnięcie",
        "porozumienie",
        "odpowiedzialność",
        "odpowiedzialny",
        "akredytowany",
        "NO TRANSLATION",
        "dokładny",
        "as",
        "osiągać",
        "osiągnięcie",
        "potwierdzenie",
        "nabyć",
        "nabywanie",
        "akrobata",
        "akcja",
        "rzeczywisty",
        "ostrość",
        "bystrość",
        "przystosować się",
        "dający się przystosować",
        "adresy",
        "adept",
        "NO TRANSLATION",
        "dodatek",
        "zachwycający",
        "admirał",
        "podziw",
        "podziwiać",
        "wielbiciel",
        "dopuszczalny",
        "godny podziwu",
        "adoracja",
        "adorować",
        "postęp",
        "zaawansowane",
        "postęp",
        "korzyść",
        "korzystny",
        "Adwent",
        "przygoda",
        "ryzykowny",
        "wskazany",
        "doradzać",
        "doradca",
        "rzecznictwo",
        "estetyczny",
        "estetyka",
        "uprzejmy",
        "tkliwość",
        "stowarzyszony",
        "potwierdzać",
        "afirmacja",
        "twierdzący",
        "afirmatywnie",
        "zamożność",
        "zamożny",
        "pozwolić sobie",
        "NO TRANSLATION",
        "zwinny",
        "zwinność",
        "Zgodzić się",
        "przyjemny",
        "Zgoda",
        "zgodzić się",
        "umowa",
        "rolnictwo",
        "przed siebie",
        "pomoc",
        "pomocnictwo",
        "alabaster",
        "czujność",
        "NO TRANSLATION",
        "żywy",
        "uspokajać",
        "wierność",
        "Allegro",
        "łagodzić",
        "ulga",
        "sprzymierzony",
        "dopuszczalne",
        "wabić",
        "pociągający",
        "sprzymierzyć",
        "wszechmocny",
        "aloha",
        "zadziwiająco",
        "ambasador",
        "ambicja",
        "polepszyć",
        "Amen",
        "odpowiedzialny",
        "modyfikować",
        "odszkodowanie",
        "uprzejmość",
        "sympatyczny",
        "przyjazny",
        "amnestia",
        "NO TRANSLATION",
        "bawić",
        "rozbawiony",
        "rozrywka",
        "zabawny",
        "analityk",
        "Kotwica",
        "zamocowanie",
        "anioł",
        "anielski",
        "animować",
        "ożywiony",
        "antybiotyki",
        "antidotum",
        "przeciwgrzybicze",
        "antyczny",
        "antyseptyczny",
        "pewność siebie",
        "przepraszający",
        "przepraszać",
        "przeprosiny",
        "apostoł",
        "oklaski",
        "uznanie",
        "aprobata",
        "zatwierdzenie",
        "zatwierdzać",
        "pochlebny",
        "trafny",
        "uzdolnienie",
        "archeologia",
        "żarliwy",
        "zapał",
        "arystokracja",
        "arystokratyczny",
        "zbroja",
        "aromat",
        "wzbudzać",
        "szyk",
        "sztuka",
        "artykułować",
        "artykulacja",
        "rzemieślnik",
        "NO TRANSLATION",
        "artystyczny",
        "przewaga",
        "wzlot",
        "dążenie",
        "aspirować",
        "ambitny",
        "montaż",
        "zgoda",
        "twierdząc",
        "majątek",
        "wspierać",
        "wsparcie",
        "współpracownik",
        "łagodzić",
        "zapewnienie",
        "zapewniony",
        "NO TRANSLATION",
        "zdziwienie",
        "astrolog",
        "astronauta",
        "astronom",
        "bystry",
        "sportowiec",
        "atletyczny",
        "atom",
        "odpokutować",
        "pokuta",
        "Załącznik",
        "osiągalny",
        "osiągnięcie",
        "obsługujący",
        "Uwaga",
        "uważny",
        "zaświadczać",
        "adwokat",
        "atrakcja",
        "atrakcyjność",
        "zwiększać",
        "sierpień",
        "ciocia",
        "aura",
        "pomyślny",
        "autentyczny",
        "autentyczność",
        "autor",
        "autorytatywny",
        "autorytet",
        "upoważnienie",
        "upoważniony",
        "awatara",
        "nagroda",
        "ay",
        "zawsze",
        "dziecko",
        "bakalaureat",
        "kręgosłup",
        "saldo",
        "zrównoważony",
        "ballada",
        "balet",
        "balotować",
        "balsam",
        "bankiet",
        "chrzest",
        "chrzcielny",
        "bard",
        "okazja",
        "Koszykówka",
        "bastion",
        "kąpiel",
        "Belka",
        "rozpromieniony",
        "upiększanie",
        "piękny",
        "upiększać",
        "piękno",
        "podłoże skalne",
        "piwo",
        "przystało",
        "zaprzyjaźnić się z",
        "wierząc",
        "dobroczyńca",
        "korzystny",
        "zasiłek",
        "życzliwość",
        "łagodny",
        "kuszetka",
        "narzeczony",
        "doskonalenie",
        "napój",
        "biblijny",
        "dwujęzyczny",
        "narodziny",
        "urodziny",
        "nienaganny",
        "błogosławić",
        "błogosławiony",
        "błogosławieństwo",
        "błogosławieństwa",
        "błogość",
        "błogi",
        "bezkrwawy",
        "kwiat",
        "kwitnąć",
        "ochroniarz",
        "pogrubienie",
        "śmiałość",
        "wzmocnić",
        "szczęście",
        "NO TRANSLATION",
        "premia",
        "książkowy",
        "księgarnia",
        "dar",
        "hojny",
        "hojność",
        "bukiet",
        "mózg",
        "odwaga",
        "śniadanie",
        "ślubny",
        "panna młoda",
        "pan młody",
        "druhna",
        "rozjaśnić",
        "jasność",
        "znakomity",
        "brokat",
        "brat",
        "braterstwo",
        "braterski",
        "kumpel",
        "budować",
        "budynek",
        "buldog",
        "kuloodporny",
        "boja",
        "buss",
        "lokaj",
        "maślany",
        "hoża",
        "brzęczeć",
        "taksówka",
        "gabinet",
        "kawiarnia",
        "kalkulator",
        "cielę",
        "spokojna",
        "kanarek",
        "szczery",
        "kandydat",
        "kandyzowany",
        "kapitalista",
        "kapitan",
        "Urzec",
        "urzekający",
        "kariera",
        "ostrożny",
        "ostrożnie",
        "pieścić",
        "dozorca",
        "kolęda",
        "kaskada",
        "gotówka",
        "kategoryczny",
        "zaopatrywać",
        "środek przeczyszczający",
        "katedra",
        "ostrożny",
        "ostrożnie",
        "słynny",
        "świętować",
        "uroczystość",
        "niebiański",
        "Centrum",
        "centurion",
        "mózgowy",
        "ceremonia",
        "pewność",
        "przewodniczący",
        "przewodnicząca",
        "mistrz",
        "intonować",
        "rumak",
        "charytatywny",
        "dobroczynność",
        "urok",
        "uroczy",
        "czystość",
        "szczękając",
        "lista kontrolna",
        "dopingować",
        "wesoły",
        "wesołość",
        "doping",
        "NO TRANSLATION",
        "chemik",
        "kochać",
        "wiśnia",
        "wódz",
        "dziecko",
        "dzieciństwo",
        "ćwierkanie",
        "dłuto",
        "rycerskość",
        "czekolada",
        "wybór",
        "chór",
        "chóralny",
        "chór",
        "wybrany",
        "chowder",
        "kronika",
        "chichot",
        "kościół",
        "cydr",
        "obrzezanie",
        "obywatel",
        "cywilny",
        "grzeczność",
        "cywilizacja",
        "cywilizowany",
        "jasnowidz",
        "klaskać",
        "wyjaśniać",
        "klasyczny",
        "klasyczny",
        "klasyka",
        "klasyfikować",
        "czysty",
        "czyszczenie",
        "czystość",
        "czysty",
        "oczyścić",
        "oczyszczanie",
        "luz",
        "jasność",
        "urzędniczy",
        "sprytny",
        "spryt",
        "punkt kulminacyjny",
        "bliskość",
        "zamknięcie",
        "NO TRANSLATION",
        "błazen",
        "koalicja",
        "Wybrzeże",
        "współistnieć",
        "przekonywający",
        "poznawczy",
        "konsekwencja",
        "zgodny",
        "spoisty",
        "zbiorowo",
        "pułkownik",
        "kolosalny",
        "komfort",
        "dowódca",
        "imponujący",
        "uczcić",
        "uczczenie pamięci",
        "pamiątkowy",
        "pochwalić",
        "chwalebny",
        "komentator",
        "zobowiązany",
        "komandor",
        "wspólnota",
        "komunikować się",
        "rozmowny",
        "komunia",
        "społeczność",
        "komutacja",
        "łagodzić",
        "towarzysz",
        "współczucie",
        "współczujący",
        "zgodność",
        "zgodny",
        "zniewalający",
        "kompensować",
        "wyrównawczy",
        "kompetencja",
        "kompetencja",
        "kompetentny",
        "samozadowolenie",
        "komplement",
        "uzupełniający",
        "całkowicie",
        "kompletność",
        "wypełniając",
        "ukończenie",
        "spełnienie",
        "zgodny",
        "NO TRANSLATION",
        "opanowany",
        "kompozytor",
        "opanowanie",
        "zrozumieć",
        "wszechstronny",
        "towarzysz",
        "koncentryczny",
        "pojednanie",
        "podsumowując",
        "zgoda",
        "zgodność",
        "kondolencje",
        "przebaczyć winę",
        "sprzyjający",
        "przewodność",
        "konfederat",
        "pewność siebie",
        "pewni",
        "zatwardziały",
        "zgodność",
        "pokrewny",
        "gratulacyjny",
        "kongregacja",
        "stosowność",
        "znawca",
        "sumienie",
        "sumienny",
        "świadomość",
        "poświęcenie",
        "ochrona",
        "chronić",
        "znaczny",
        "taktowny",
        "konsystencja",
        "konsola",
        "spółgłoska",
        "stałość",
        "stały",
        "konstytucyjny",
        "zbudować",
        "wytrawny",
        "kontakt",
        "kontemplacja",
        "zadowolony",
        "dalej",
        "kontur",
        "przyczynić się",
        "współpracownik",
        "wygoda",
        "wygodna",
        "klasztor",
        "Konwencja",
        "biegły",
        "konwersacyjny",
        "konwertować",
        "przekonać",
        "chłodny",
        "chłód",
        "współpracować",
        "współpracujący",
        "współpraca",
        "spółdzielnia",
        "rdzeń",
        "koronacja",
        "Korporacja",
        "cielesny",
        "poprawczy",
        "korespondencja",
        "potwierdzać",
        "kosmopolityczny",
        "przytulny",
        "rada",
        "rada",
        "doradca",
        "liczyć",
        "hrabina",
        "odwaga",
        "odważny",
        "uprzejmy",
        "kurtuazja",
        "zaloty",
        "zatoczka",
        "przymierze",
        "kolebka",
        "rzemiosło",
        "rzemieślnik",
        "krem",
        "Stwórz",
        "twórczy",
        "wiara",
        "poświadczenie",
        "wiarygodność",
        "wiarygodny",
        "kredyt",
        "NO TRANSLATION",
        "zaksięgowane",
        "crescendo",
        "krytyka",
        "koronny",
        "istotny",
        "kryształ",
        "przytulać",
        "kulinarny",
        "kulminacja",
        "kultywować",
        "uprawiany",
        "uprawa",
        "kultura",
        "uleczalny",
        "ciekawość",
        "kędzior",
        "poduszka",
        "klient",
        "uroczy",
        "nożyce",
        "dama",
        "taniec",
        "śmiały",
        "kochanie",
        "ozdobny",
        "córka",
        "świt",
        "sprawa",
        "drogi",
        "debata",
        "przyzwoitość",
        "przyzwoity",
        "deklaratywny",
        "poświęcenie",
        "bronić",
        "broniony",
        "obrońca",
        "bronić",
        "obrona",
        "szacunek",
        "ostateczny",
        "stopień",
        "przemiły",
        "delegat",
        "obradować",
        "pyszne",
        "rozkosz",
        "zachwycony",
        "zachwycający",
        "uwolnienie",
        "dostawa",
        "demokracja",
        "dający się udowodnić",
        "wskazujący",
        "głębokość",
        "opisowy",
        "zasłużyć",
        "zasłużony",
        "projektant",
        "pożądany",
        "pragnąc",
        "pragnący",
        "przeznaczenie",
        "wykryć",
        "wykrycie",
        "determinacja",
        "ustalona",
        "rozwijać",
        "nabożny",
        "pobożny",
        "zręczność",
        "diament",
        "Dziennik",
        "słownik",
        "dydaktyczny",
        "dietetyczny",
        "godny",
        "godność",
        "pracowitość",
        "obiad",
        "dyplomacja",
        "dyplomatyczny",
        "dyrektor",
        "odkrycie",
        "NO TRANSLATION",
        "dyskrecja",
        "uznaniowe",
        "dyskusja",
        "dezynfekcja",
        "unieszkodliwiony",
        "rozpowszechniać",
        "destylacja",
        "różnica",
        "śpiewka",
        "urozmaicony",
        "dywersja",
        "boskość",
        "lekarz",
        "sprawca",
        "zawzięty",
        "delfin",
        "don",
        "darowizna",
        "niewątpliwie",
        "gołąb",
        "puchaty",
        "duet",
        "książę",
        "trwałość",
        "trwały",
        "dbający",
        "chętny",
        "zapał",
        "hrabia",
        "zarabiać",
        "zadatek",
        "usilnie",
        "gorliwość",
        "łatwość",
        "serwitut",
        "NO TRANSLATION",
        "jeść",
        "ekstaza",
        "ekstatyczny",
        "pozytywny wpływ",
        "kształcić",
        "wykształcony",
        "edukacyjny",
        "efektywny",
        "skuteczność",
        "wydajność",
        "wydajny",
        "wysiłek",
        "wytrysk",
        "opracowanie",
        "podniecony",
        "starszy",
        "starsi",
        "elekt",
        "elektryczny",
        "Elektryczność",
        "elegancja",
        "elegancki",
        "podniesienie",
        "wybieralny",
        "elita",
        "elokwencja",
        "wymowny",
        "wyjaśniać",
        "emancypacja",
        "uścisk",
        "emeritus",
        "eminencja",
        "wybitny",
        "wybitnie",
        "NO TRANSLATION",
        "empatia",
        "umożliwiać",
        "naśladować",
        "włączyć",
        "włączanie",
        "zaczarować",
        "zaczarowany",
        "uroczy",
        "NO TRANSLATION",
        "zachęcać",
        "zachęta",
        "encyklopedia",
        "dążyć",
        "wyposażyć",
        "obdarowany",
        "obdarowanie",
        "wytrzymałość",
        "znieść",
        "energetyczny",
        "zaręczony",
        "ujmujący",
        "wzmacniać",
        "cieszyć się",
        "ciesząc",
        "oświecać",
        "oświecenie",
        "ożywiać",
        "wzbogacać",
        "ensemble",
        "chorąży",
        "przedsiębiorczy",
        "bawić",
        "rozrywkę",
        "zabawny",
        "zabawa",
        "entuzjazm",
        "entuzjasta",
        "NO TRANSLATION",
        "efemerydy",
        "epicki",
        "typowy przykład",
        "równość",
        "na równi",
        "równowaga",
        "sprawiedliwość",
        "zadanie",
        "erudyta",
        "esprit",
        "istotny",
        "ustanowiony",
        "szacunek",
        "estetyczny",
        "etyczny",
        "etyka",
        "zimozielony",
        "wieczny",
        "oczywisty",
        "ewolucja",
        "wywyższać",
        "egzaltacja",
        "egzaltowany",
        "przekraczać",
        "przewyższać",
        "doskonałość",
        "doskonały",
        "Wymieniać się",
        "pobudliwy",
        "pobudzenie",
        "podniecać",
        "podekscytowany",
        "podniecenie",
        "ekscytujący",
        "przykładowy",
        "zwolnienie",
        "podekscytowanie",
        "nawoływać",
        "napomnienie",
        "istnienie",
        "egzotyczny",
        "oczekiwać",
        "oczekiwanie",
        "korzystny",
        "wyprawa",
        "doświadczony",
        "ekspert",
        "ekspertyza",
        "wyjaśniać",
        "znakomity",
        "znakomicie",
        "poszerzać",
        "rozległy",
        "dodatkowy",
        "niezwykły",
        "wydobyć",
        "wylewność",
        "ułatwiać",
        "fakty",
        "Wydział",
        "NO TRANSLATION",
        "targi",
        "dość",
        "wiara",
        "wierny",
        "sława",
        "znajomy",
        "znajomość",
        "sławny",
        "znakomicie",
        "fantazyjny",
        "fanfara",
        "fascynujący",
        "fascynacja",
        "modny",
        "bezbłędny",
        "korzystny",
        "ulubiony",
        "faworyzowanie",
        "nieustraszony",
        "wyczyn",
        "cecha",
        "szczęście",
        "facet",
        "wspólnota",
        "Płeć żeńska",
        "płodny",
        "zapał",
        "festiwal",
        "uroczysty",
        "NO TRANSLATION",
        "wierność",
        "fiesta",
        "Wreszcie",
        "gałganek",
        "impas",
        "kula ognia",
        "ogniotrwały",
        "jędrność",
        "NO TRANSLATION",
        "dopasowywanie",
        "osprzęt",
        "pochlebny",
        "flota",
        "elastyczność",
        "kwiatowy",
        "pływ",
        "kwiecisty",
        "spłukać",
        "latający",
        "skupiać",
        "sentyment",
        "jedzenie",
        "piłka nożna",
        "wyrozumiałość",
        "dziobowy",
        "przodkowie",
        "powyższy",
        "majster",
        "prekursor",
        "przewidywać",
        "przewidywany",
        "dalekowzroczność",
        "fałszować",
        "przebaczyć",
        "wybaczony",
        "wyrozumiały",
        "kształtujący",
        "formuła",
        "NO TRANSLATION",
        "nadchodzący",
        "ufortyfikować",
        "hart",
        "twierdza",
        "szczęśliwy",
        "fortuna",
        "Naprzód",
        "uznany",
        "Fundacja",
        "pachnący",
        "szczery",
        "szczerość",
        "braterski",
        "wolność",
        "swobodnie",
        "przyjaciel",
        "życzliwość",
        "przyjazny",
        "przyjaźń",
        "rozbrykany",
        "wybryk",
        "oszczędny",
        "owocny",
        "spełnić",
        "spełnienie",
        "pełny",
        "całkowicie",
        "zabawa",
        "fundamentalny",
        "bezpiecznik",
        "połączenie",
        "zdobyć",
        "zyskuje",
        "dzielny",
        "galanteria",
        "w bród",
        "ogród",
        "granat",
        "garnizon",
        "gazeta",
        "koło zębate",
        "klejnot",
        "generał",
        "hojność",
        "hojny",
        "bródkowy",
        "geniusz",
        "dystyngowany",
        "pan",
        "łagodność",
        "szlachta",
        "prawdziwy",
        "pelargonia",
        "prezent",
        "utalentowany",
        "gigantyczny",
        "chichot",
        "dźwigar",
        "dający",
        "zadowolony",
        "radość",
        "radość",
        "poślizg",
        "ogienek",
        "błyszczące",
        "gloryfikacja",
        "chwalić",
        "chwała",
        "połysk",
        "poświata",
        "rozjarzony",
        "Bóg",
        "pobożny",
        "wybawienie",
        "złoto",
        "dobry",
        "niemały",
        "dobroć",
        "dobra",
        "życzliwość",
        "wspaniały",
        "ewangelia",
        "rządzić",
        "wdzięk",
        "wdzięczny",
        "łaskawy",
        "łaskawie",
        "ukończenie szkoły",
        "wnuki",
        "wielkość",
        "babcia",
        "dotacja",
        "Zgoda",
        "wdzięczny",
        "zaspokoić",
        "wdzięczność",
        "większy",
        "wielkość",
        "Zielony",
        "Powitanie",
        "towarzyski",
        "szeroki uśmiech",
        "przemiał",
        "piasek",
        "podkład",
        "rosnąć",
        "wzrost",
        "gwarancja",
        "strzec",
        "opiekun",
        "opieka",
        "gubernatorski",
        "poradnictwo",
        "przewodnik",
        "przewodnik",
        "guru",
        "wnętrzności",
        "gimnastyk",
        "siedlisko",
        "krzepki",
        "poręczny",
        "szczęśliwie",
        "szczęście",
        "szczęśliwy",
        "wytrzymały",
        "harmonijnie",
        "Harmonia",
        "żniwa",
        "przystań",
        "postępy",
        "uzdrowić",
        "gojenie",
        "zdrowy",
        "zdrowy",
        "serdeczny",
        "ognisko",
        "serdecznie",
        "niebiański",
        "niebiosa",
        "waga",
        "kask",
        "pomocnik",
        "pomocny",
        "zielarski",
        "bohater",
        "heroiczny",
        "heroizm",
        "bohaterka",
        "bohaterstwo",
        "szczyt",
        "wesoły",
        "wesołość",
        "zatrudnić",
        "hobby",
        "święto",
        "świętość",
        "święty",
        "hołd",
        "homologia",
        "szczery",
        "uczciwość",
        "kochanie",
        "Miesiąc miodowy",
        "honor",
        "honorowy",
        "nadzieja",
        "pełen nadziei",
        "horyzont",
        "gościnność",
        "gospodarstwo domowe",
        "gospodarowanie",
        "przytulać",
        "humanitarny",
        "humanitarny",
        "ludzkość",
        "Upokorzony",
        "pokornie",
        "pokora",
        "humorysta",
        "humorystyczny",
        "Hurra",
        "uprawa roli",
        "Cicho",
        "Chata",
        "higieniczny",
        "hymn",
        "idealizm",
        "idol",
        "NO TRANSLATION",
        "oświetlenie",
        "zilustrować",
        "znakomity",
        "obdarzony wyobraźnią",
        "nieskazitelny",
        "ogromny",
        "zanurzać",
        "nieśmiertelny",
        "dodawać",
        "bezstronny",
        "bezstronność",
        "bez zarzutu",
        "nieprzepuszczalny",
        "znaczenie",
        "ważny",
        "imponować",
        "wrażenie",
        "ulepszać",
        "ulepszony",
        "poprawa",
        "poprawa",
        "improwizować",
        "niezbywalny",
        "inauguracja",
        "zjadliwy",
        "zawierać",
        "w zestawie",
        "włącznie z",
        "włącznie",
        "zwiększać",
        "niezatarty",
        "odszkodowanie",
        "niezależność",
        "niezniszczalna",
        "indywidualność",
        "nieposkromiony",
        "niewypowiedziany",
        "niedrogi",
        "nieomylny",
        "Dziecko",
        "nieskończony",
        "nieskończoność",
        "wpływowy",
        "Informacja",
        "pomysłowy",
        "dziedzictwo",
        "nie do naśladowania",
        "niewinność",
        "niewinny",
        "niewinnie",
        "nieszkodliwy",
        "wprowadzać innowacje",
        "innowacja",
        "informujący się",
        "zapytanie ofertowe",
        "ciekawy",
        "nierozerwalny",
        "insygnia",
        "inspektor",
        "Inspiracja",
        "inspirować",
        "natchniony",
        "instynktowny",
        "pouczać",
        "instrukcja",
        "instruktor",
        "instrumentalny",
        "ubezpieczać",
        "nienaruszony",
        "integralność",
        "intelekt",
        "intelektualny",
        "inteligencja",
        "inteligentny",
        "zamierzony",
        "stosunek płciowy",
        "zainteresowanie",
        "zainteresowany",
        "ciekawy",
        "wnętrze",
        "tymczasowy",
        "interludium",
        "intymny",
        "intonacja",
        "nieustraszony",
        "intuicja",
        "intuicyjny",
        "niezmiennie",
        "wynalazczy",
        "wynalazca",
        "zbadać",
        "orzeźwiać",
        "zaproszenie",
        "Zapraszam",
        "atrakcyjny",
        "żelazo",
        "nieskracalny",
        "niezbity",
        "pula",
        "dżem",
        "NO TRANSLATION",
        "praca",
        "Przystąpić",
        "Dołączył",
        "żartowniś",
        "żartować",
        "dziennikarz",
        "podróż",
        "jowialny",
        "radość",
        "radosny",
        "radosny",
        "uradowany",
        "jubileusz",
        "sądowy",
        "rozsądny",
        "skok",
        "sprawiedliwość",
        "uzasadniony",
        "usprawiedliwienie",
        "pamiątka",
        "rozpoznać",
        "myśl przewodnia",
        "zwornik",
        "uprzejmy",
        "życzliwość",
        "krewni",
        "król",
        "pocałunek",
        "kotek",
        "dryg",
        "rycerz",
        "porozumiewawczy",
        "wiedza, umiejętności",
        "sława",
        "praca",
        "owieczka",
        "wylądować",
        "wylądował",
        "laser",
        "chwalebny",
        "śmiech",
        "śmiać się",
        "śmiech",
        "uruchomić",
        "laureat",
        "laur",
        "laury",
        "rozrzutny",
        "legalny",
        "prowadzić",
        "lider",
        "liga",
        "uczyć się",
        "uczenie się",
        "wykładowca",
        "dryf",
        "prawny",
        "zalegalizowane",
        "legendarny",
        "czytelność",
        "czytelny",
        "wolny czas",
        "spokojnie",
        "lemat",
        "łagodny",
        "lekcja",
        "wyliterowany",
        "poziom",
        "wpływ",
        "uwalniać",
        "oswobodzenie",
        "wolność",
        "biblioteka",
        "siła napędowa",
        "latarnia morska",
        "gust",
        "językoznawca",
        "Lew",
        "gibki",
        "logiczny",
        "długowieczność",
        "panowanie",
        "sympatyczny",
        "miłość",
        "śliczny",
        "NO TRANSLATION",
        "kochanek",
        "kochający",
        "wierny",
        "lojalność",
        "szczęście",
        "Szczęściarz",
        "soczysty",
        "połysk",
        "lśniący",
        "bujny",
        "luksusowy",
        "luksus",
        "lira",
        "liryczny",
        "magiczny",
        "magnes",
        "magnetyzm",
        "magnetyt",
        "wspaniałość",
        "wspaniały",
        "dziewica",
        "Główny",
        "filar",
        "majestatyczny",
        "majestat",
        "poważny",
        "większość",
        "zarządzanie",
        "zarządzanie",
        "mandarynka",
        "męskość",
        "zamanifestowane",
        "męski",
        "manna",
        "zmanierowany",
        "maniery",
        "producent",
        "Marsz",
        "wyraźny",
        "nadający się do sprzedaży",
        "markiz",
        "małżeństwo",
        "szpik kostny",
        "ożenić",
        "marszałek",
        "podziwiać",
        "cudowny",
        "fenomenalnie",
        "rodzaj męski",
        "masaż",
        "mistrz",
        "arcydzieło",
        "mistrzostwo",
        "kumpel",
        "małżeństwo",
        "matrona",
        "maksymalny",
        "burmistrz",
        "łąka",
        "wymierzony",
        "medal",
        "pośredniczyć",
        "mediacja",
        "mediator",
        "medyczny",
        "NO TRANSLATION",
        "śródziemnomorski",
        "składanka",
        "memento",
        "niezapomniany",
        "naprawa",
        "miesiączka",
        "mentor",
        "miłosierny",
        "Łaska",
        "łączyć",
        "zasługa",
        "zasłużony",
        "wesołość",
        "wesoły",
        "metropolita",
        "zapał",
        "mikroskopia",
        "położnictwo",
        "potężny",
        "mim",
        "pomny",
        "uważność",
        "ministerstwo",
        "cud",
        "cudowny",
        "wesołość",
        "misjonarz",
        "Model",
        "umiarkowany",
        "moderator",
        "skromny",
        "skromność",
        "pęd",
        "monetarny",
        "pieniądze",
        "mnich",
        "pomnik",
        "morał",
        "moralność",
        "moralność",
        "moździerz",
        "macierzyństwo",
        "motyw",
        "ruchomy",
        "wnioskodawca",
        "muskularny",
        "muzyka",
        "musical",
        "zmienny",
        "wzajemny",
        "drzemka",
        "przyrodnik",
        "żeglowny",
        "starannie",
        "nektar",
        "igła",
        "negocjować",
        "negocjator",
        "sąsiad",
        "nerw",
        "tulić",
        "szlachta",
        "szlachetny",
        "szlachcic",
        "nominacja",
        "normalność",
        "znaczny",
        "godne uwagi",
        "NO TRANSLATION",
        "pojęcie",
        "pokarm",
        "liczby",
        "pielęgniarka",
        "żłobek",
        "wychowanie",
        "pożywny",
        "dąb",
        "oaza",
        "przysięga",
        "posłuszeństwo",
        "cel",
        "uczynny",
        "uważny",
        "osiągalny",
        "oczywisty",
        "mieszkaniec",
        "zawód",
        "zająć",
        "oferta",
        "oficer",
        "offsetowy",
        "odgałęzienie",
        "wszechwiedzący",
        "otwartość",
        "opera",
        "dogodny",
        "okazja",
        "optymizm",
        "optymista",
        "opcja",
        "opcjonalny",
        "wyrocznia",
        "oracja",
        "orkiestra",
        "wyświęcony",
        "uporządkowany",
        "wyświęcenie",
        "organiczny",
        "organizacja",
        "zorganizować",
        "zorganizowany",
        "orgazm",
        "oryginalność",
        "zdobione",
        "ozdobny",
        "wynik",
        "przelicytować",
        "zewnętrzny",
        "uszczęśliwiony",
        "przytłaczający",
        "własność",
        "Pacyfik",
        "Podkładka",
        "wyściółka",
        "wiosłować",
        "smaczny",
        "paliatywny",
        "panaceum",
        "pióropusz",
        "NO TRANSLATION",
        "papryka",
        "wzór doskonałości",
        "najważniejszy",
        "pardon",
        "pochodzenie",
        "ciemieniowy",
        "uczestniczyć",
        "udział",
        "partner",
        "Współpraca",
        "pasja",
        "namiętny",
        "rozrywka",
        "pastor",
        "ciasto",
        "pastwisko",
        "patent",
        "cierpliwość",
        "cierpliwy",
        "patriarchalny",
        "patron",
        "patronat",
        "zapłacić",
        "pokój",
        "zgodny",
        "spokojna",
        "paw",
        "dziobać",
        "osobliwość",
        "genealogia",
        "niezrównany",
        "upodobanie",
        "dostrzec",
        "wyczuwalny",
        "bylina",
        "idealny",
        "doskonałość",
        "wykonawca",
        "akcydens",
        "pozwolenie",
        "wieczność",
        "trwałość",
        "trwały",
        "przystojny",
        "trafny",
        "farmaceutyczny",
        "filantrop",
        "filantropia",
        "filozof",
        "feniks",
        "fonetyczny",
        "Lekarz",
        "fizyka",
        "fizjologia",
        "budowa ciała",
        "wybierać",
        "piknik",
        "malowniczy",
        "pobożność",
        "pigułka",
        "poduszka",
        "pilot",
        "szczyt",
        "pionier",
        "pobożny",
        "miękisz",
        "sworzeń",
        "spokojny",
        "planowanie",
        "figlarny",
        "plac zabaw",
        "teatr",
        "przyjemne",
        "zadowolony",
        "przyjemny",
        "zastaw",
        "plenarny",
        "obfity",
        "splot",
        "śliwka",
        "pion",
        "plusz",
        "zagięcie",
        "dosadnie",
        "Policja",
        "policjant",
        "Polskie",
        "błyszczący",
        "uprzejmy",
        "uprzejmość",
        "NO TRANSLATION",
        "basen",
        "Papież",
        "popularność",
        "spopularyzowany",
        "populacja",
        "przenośny",
        "posiadać",
        "pitny",
        "moc",
        "potężny",
        "mocarnie",
        "ćwiczyć",
        "doświadczony",
        "ćwiczyć",
        "pochwała",
        "chwalony",
        "godny pochwały",
        "modlić się",
        "ostrożność",
        "poprzedzać",
        "precedens",
        "cenny",
        "precyzyjny",
        "precyzja",
        "szczególne upodobanie",
        "dominujący",
        "wybitny",
        "woleć",
        "premier",
        "lokal",
        "przygotować",
        "przygotowany",
        "przewidujący",
        "obecność",
        "obecny",
        "reprezentacyjny",
        "konserwant",
        "zachować",
        "prezydent",
        "prestiż",
        "presto",
        "ładny",
        "panować",
        "zapobieganie",
        "bezcenny",
        "duma",
        "kapłan",
        "kapłaństwo",
        "kapłański",
        "prymat",
        "podstawowa",
        "główny",
        "Elementarz",
        "książę",
        "książęcy",
        "księżniczka",
        "dyrektor",
        "dziewiczy",
        "uprzywilejowany",
        "uczciwość",
        "procedura",
        "procesja",
        "cenzor",
        "zdobyć",
        "cudowny",
        "cud",
        "producent",
        "produkujący",
        "produkcja",
        "produktywny",
        "wydajność",
        "zawód",
        "profesjonalny",
        "profesor",
        "biegłość",
        "biegły",
        "obfity",
        "postęp",
        "postęp",
        "progresywny",
        "płodny",
        "rozgłos",
        "w widocznym miejscu",
        "obietnica",
        "obiecujący",
        "awans",
        "rekwizyt",
        "właściwy",
        "prorok",
        "profilaktyczny",
        "propozycja",
        "perspektywa",
        "prosperować",
        "dobrobyt",
        "dostatni",
        "ochraniać",
        "ochrona",
        "ochronny",
        "ochraniacz",
        "dumny",
        "okazać się",
        "przysłowiowy",
        "zapewniać",
        "że",
        "roztropność",
        "ostrożny",
        "psalm",
        "publiczny",
        "Ciągnąć",
        "ambona",
        "punktualny",
        "punktualność",
        "szczeniak",
        "czysto",
        "oczyszczenie",
        "oczyścić",
        "purysta",
        "czystość",
        "mruczeć",
        "osobliwy",
        "wykwalifikowany",
        "kwalifikacyjny",
        "zadanie",
        "pytanie",
        "szybkość",
        "spokojny",
        "cichy",
        "chinina",
        "blask",
        "promienny",
        "promieniować",
        "radio",
        "skupiony",
        "zachwyt",
        "racjonalny",
        "czytelnik",
        "łatwo",
        "gotowość",
        "czytanie",
        "potwierdzać",
        "real",
        "powód",
        "reasekuracja",
        "uspokajać",
        "przylga",
        "przerobić",
        "Odebrane",
        "odbieranie",
        "NO TRANSLATION",
        "odwzajemniać",
        "regeneracja",
        "układać",
        "rozpoznawalny",
        "polecić",
        "pojednanie",
        "zrewidowanie",
        "zrekonstruować",
        "rekonstrukcja",
        "rejestrator",
        "odzyskać",
        "poprawa",
        "rekreacja",
        "rekreacyjny",
        "prostować",
        "odkupienie",
        "wyrównać",
        "oczyścić",
        "udoskonalenie",
        "reforma",
        "reformacja",
        "reformator",
        "orzeźwiający",
        "odnawiać",
        "królewski",
        "regent",
        "prawidłowość",
        "regulować",
        "zrehabilitować",
        "rehabilitacja",
        "zwracać koszty",
        "zwrot kosztów",
        "wzmocnienie",
        "przywracać na stanowisko",
        "cieszyć",
        "radość",
        "odmładzać",
        "odmłodzony",
        "relaks",
        "istotnych",
        "niezawodność",
        "niezawodny",
        "poleganie",
        "ulga",
        "łagodzi",
        "przerobić",
        "znakomity",
        "NO TRANSLATION",
        "zaradzić",
        "umorzenie",
        "przebudować",
        "renesans",
        "renderowanie",
        "odnowienie",
        "odnawiać",
        "renowacja",
        "rozgłos",
        "słynny",
        "zreorganizować",
        "naprawa",
        "odwdzięczyć się",
        "żałować",
        "uzupełniać",
        "nasycony",
        "reporter",
        "odpoczynek",
        "reprezentowane",
        "rozrodczy",
        "renomowany",
        "ratować",
        "rezerwować",
        "Mieszkaniec",
        "sprężysty",
        "oporny",
        "zdecydowanie",
        "zasoby",
        "Poszanowanie",
        "poważanie",
        "poważny",
        "pełen szacunku",
        "co do",
        "wyrazy szacunku",
        "wytchnienie",
        "olśniewający",
        "odpowiedzialny",
        "czuły",
        "odpoczynek",
        "spokojny",
        "restytucja",
        "wzmacniający",
        "przywracanie",
        "powściągliwość",
        "wznowienie",
        "zatrzymywanie",
        "Reunion",
        "biesiada",
        "rozkoszuje się",
        "czcić",
        "cześć",
        "czcigodny",
        "zaduma",
        "Poprawić",
        "odrodzenie",
        "rewolucyjny",
        "nagroda",
        "rytm",
        "rytmiczny",
        "faborek",
        "bogactwo",
        "jeździec",
        "sprawiedliwy",
        "prawowity",
        "słusznie",
        "dojrzały",
        "dojrzewać",
        "podniesienie",
        "nitowanie",
        "terenówka",
        "krzepki",
        "skała",
        "pręt",
        "hulaszczy",
        "romans",
        "romantyczny",
        "romantyzm",
        "broić",
        "ukorzeniony",
        "różany",
        "rota",
        "rutyna",
        "rodzina królewska",
        "rubryka",
        "litość",
        "bezpieczny",
        "zabezpieczenie",
        "szałwia",
        "święty",
        "świętobliwy",
        "wynagrodzenie",
        "wystający",
        "zbawienny",
        "salut",
        "zbawienie",
        "maść",
        "samuraj",
        "uświęcenie",
        "uświęcać",
        "sanktuarium",
        "optymistyczny",
        "sanitarny",
        "satyna",
        "zadowalająco",
        "zadowolona",
        "zapisać",
        "oszczędności",
        "smak",
        "cząber",
        "rozumieć",
        "uczony",
        "stypendium",
        "naukowy",
        "naukowiec",
        "NO TRANSLATION",
        "wynik",
        "uczony w piśmie",
        "scenariusz",
        "byczy",
        "rzeźba",
        "morze",
        "foka",
        "zaprawiony",
        "sekretariat",
        "starszeństwo",
        "rewelacyjny",
        "sens",
        "wrażliwość",
        "mądrze",
        "zmysłowość",
        "zmysłowy",
        "sentymentalny",
        "sentymentalizm",
        "strażnik",
        "spokój",
        "kazanie",
        "serum",
        "osadnik",
        "seks",
        "kształt",
        "kształtny",
        "dzielić",
        "schron",
        "pasterz",
        "blask",
        "świecący",
        "zakupy",
        "ramię",
        "sprytny",
        "jedwab",
        "uproszczać",
        "szczery",
        "szczerosc",
        "śpiewać",
        "pojedynczo",
        "Pan",
        "siostrzeństwo",
        "wykwalifikowany",
        "zręczny",
        "niebo",
        "łupek",
        "gładki",
        "smukły",
        "szczupły",
        "uśmiech",
        "uśmiechając się",
        "uderzony",
        "gładkość",
        "chichot",
        "trzeźwość",
        "towarzyski",
        "pocieszenie",
        "żołnierz",
        "solidny",
        "solidność",
        "rozwiązanie",
        "wypłacalność",
        "sonar",
        "sonata",
        "sonet",
        "dźwięczny",
        "łagodzić",
        "kojący",
        "NO TRANSLATION",
        "solidność",
        "zupa",
        "spa",
        "przestronny",
        "spaniel",
        "blask",
        "specjalny",
        "NO TRANSLATION",
        "przemówienie",
        "szybki",
        "pisownia",
        "przyprawa",
        "duch",
        "duchy",
        "wspaniały",
        "splendor",
        "sponsor",
        "nieskazitelny",
        "małżonka",
        "świerk",
        "stabilny",
        "staccato",
        "nierdzewny",
        "ogier",
        "rosły",
        "wytrzymałość",
        "na stojąco",
        "gwiazda",
        "gwiezdny",
        "gwiaździsty",
        "dostojny",
        "komunikat",
        "statua",
        "status",
        "zagorzały",
        "niezłomny",
        "gwiezdny",
        "Steward",
        "spokój",
        "sklep",
        "bezpośredni",
        "strategiczny",
        "strateg",
        "siła",
        "wzmacniać",
        "wzmacniający",
        "uderzający",
        "uderzająco",
        "silnie",
        "Struktura",
        "stadnina",
        "badanie",
        "silny",
        "sublimacja",
        "substancja",
        "rzeczownik",
        "osiągnąć sukces",
        "kolejny",
        "powodzenie",
        "odnoszący sukcesy",
        "zwięzły",
        "dostateczność",
        "cukier",
        "odpowiedni",
        "duszny",
        "słońce",
        "słoneczny",
        "zachód słońca",
        "światło słoneczne",
        "wspaniały",
        "nadludzki",
        "lepszy",
        "wyższość",
        "nadczłowiek",
        "Super gwiazda",
        "błaganie",
        "kieszonkowe dzieci",
        "Dostawa",
        "utrzymany",
        "kibic",
        "wspierający",
        "najwyższy",
        "doskonale",
        "pewność",
        "domysł",
        "nieprześcigniony",
        "niespodzianka",
        "geodezja",
        "przetrwać",
        "przysięgać",
        "Słodkie",
        "kochanie",
        "kochanie",
        "słodycz",
        "słodycze",
        "szybki",
        "pływać",
        "symboliczny",
        "symetryczny",
        "symetria",
        "współczujący",
        "współczucie",
        "symfonia",
        "synchronizować",
        "synergistyczny",
        "synod",
        "takt",
        "opowieść",
        "talent",
        "talizman",
        "rozmowa",
        "opalony",
        "zadanie",
        "gustowny",
        "pyszne",
        "nauczać",
        "nauczyciel",
        "technologia",
        "wstrzemięźliwość",
        "hartowany",
        "możliwy do utrzymania",
        "wytrwały",
        "wytrwałość",
        "dzierżawa",
        "najemca",
        "delikatny",
        "czułość",
        "wdzięczny",
        "święto Dziękczynienia",
        "teoretyczny",
        "terapeutyczny",
        "lecznictwo",
        "NO TRANSLATION",
        "rasowy",
        "rozważny",
        "zamyślenie",
        "oszczędność",
        "dreszczyk",
        "porywający",
        "kwitnie",
        "tron",
        "łaskotać",
        "dekarstwo",
        "aktualny",
        "blichtr",
        "tytuł",
        "toast",
        "tolerancyjny",
        "tolerancja",
        "Top",
        "wytrzymałość",
        "wieża",
        "wysoki",
        "tradycyjny",
        "cichy",
        "spokój",
        "transcendencja",
        "nadzmysłowy",
        "podróżny",
        "skarb",
        "drzewo",
        "niesamowicie",
        "tendencja",
        "modny",
        "dopływ",
        "hołd",
        "wymuskany",
        "triumf",
        "tryumfalny",
        "trofeum",
        "rozejm",
        "PRAWDZIWE",
        "wierny",
        "prawda",
        "prawdomówność",
        "kuratela",
        "korepetytor",
        "bliźniak",
        "migotanie",
        "ostatecznie",
        "rozjemca",
        "jednomyślność",
        "jednomyślny",
        "skromny",
        "bezinteresowny",
        "niezniszczalny",
        "nieprzerwany",
        "niewymuszony",
        "podkreślać",
        "zrozumienie",
        "przyjąć do ubezpieczenia",
        "niepodzielny",
        "nieśmiertelny",
        "jednoznacznie",
        "rozwijać się",
        "zjednoczenie",
        "równomiernie",
        "niezainfekowany",
        "wyjątkowy",
        "unisono",
        "jednolity",
        "zjednoczony",
        "jedność",
        "Uniwersytet",
        "Nieograniczony",
        "skromny",
        "niewątpliwy",
        "bezsprzecznie",
        "niezaprzeczony",
        "bez szwanku",
        "bezinteresowny",
        "niezrównany",
        "niezachwiany",
        "podnieść",
        "pionowo",
        "przydatność",
        "bileter",
        "zwykły",
        "użyteczność",
        "utopijny",
        "wakacje",
        "szczepionka",
        "dzielny",
        "NO TRANSLATION",
        "cenny",
        "awangarda",
        "pokonać",
        "aksamit",
        "aksamitny",
        "czcigodny",
        "cześć",
        "prawdziwość",
        "zielenisty",
        "weryfikacja",
        "zweryfikowany",
        "zaiste",
        "prawdziwy",
        "wiosenny",
        "rozmach",
        "weteran",
        "wikariusz",
        "zwycięzca",
        "zwycięski",
        "zwycięstwo",
        "czujność",
        "czujny",
        "wigor",
        "energiczny",
        "wieśniak",
        "potwierdzone",
        "windykacja",
        "dziewica",
        "dziewictwo",
        "cnota",
        "cnotliwy",
        "wizja",
        "wizjoner",
        "odwiedzić",
        "gość",
        "istotny",
        "witalność",
        "żywy",
        "żywy",
        "słownictwo",
        "wolontariusz",
        "zmysłowy",
        "ręczyć",
        "przysięga",
        "wynagrodzenie",
        "Gwarancja",
        "wojownik",
        "pies podwórzowy",
        "czujny",
        "stróż",
        "wodoodporny",
        "bogactwo",
        "wodoodporny",
        "mile widziana",
        "biały",
        "biel",
        "zdrowy",
        "furtka",
        "rozpowszechniony",
        "chętnie",
        "chęci",
        "gratka",
        "zwycięzca",
        "zwycięski",
        "wygrana",
        "bezprzewodowy",
        "wis",
        "mądrość",
        "mądry",
        "dowcip",
        "wytrzymać",
        "rozum",
        "dowcipny",
        "czarodziej",
        "łono",
        "wspaniale",
        "fenomenalnie",
        "cudowny",
        "słowo",
        "pracujący",
        "kult",
        "wartość",
        "godny",
        "wot",
        "pisarz",
        "młody",
        "mniejszy",
        "młodość",
        "gorliwość",
        "gorliwy",
        "skórka owocowa",
    ]
)

_negative = set(
    [
        "porzucić",
        "opuszczony",
        "porzucenie",
        "uprowadzenie",
        "anormalny",
        "aberracja",
        "czuć wstręt",
        "odrażający",
        "nikczemny",
        "nieprawidłowy",
        "znieść",
        "zniesienie",
        "wstrętny",
        "wstręt",
        "anulować",
        "poronienie",
        "nieudany",
        "przetarcie",
        "unieważnić",
        "ropień",
        "brak",
        "nieobecny",
        "bumelant",
        "absencja",
        "absurdalny",
        "absurdalność",
        "nadużycie",
        "bezdenny",
        "przepaść",
        "wypadek",
        "przypadkowy",
        "przeklęty",
        "oskarżenie",
        "biernik",
        "oskarżony",
        "oskarżyciel",
        "oskarżając",
        "ból",
        "zbolały",
        "kwas",
        "zaskarżalny",
        "sumator",
        "nałóg",
        "tłuszczowy",
        "orzec",
        "napomnienie",
        "dryfujący",
        "zafałszowany",
        "cudzołóstwo",
        "przeciwnik",
        "niekorzystny",
        "nieszczęście",
        "dotknąć",
        "cierpiący",
        "cierpienie",
        "afront",
        "przestraszony",
        "następstwa",
        "posmak",
        "pogarsza się",
        "obciążający",
        "pogorszenie",
        "agresja",
        "agresywny",
        "agresor",
        "przerażony",
        "poruszony",
        "podniecenie",
        "bolesny",
        "agonia",
        "na mieliźnie",
        "chorować",
        "schorowany",
        "bezcelowy",
        "powietrze",
        "alarm",
        "alarmujące",
        "alkoholizm",
        "obcy",
        "zrazić",
        "wyobcowany",
        "alienacja",
        "alimenty",
        "zarzut",
        "twierdzić",
        "z dala",
        "sprzeczka",
        "dwuznaczny",
        "zasadzka",
        "amnezja",
        "amfetaminy",
        "anakonda",
        "analny",
        "anarchizm",
        "anarchista",
        "anarchia",
        "anatema",
        "starożytny",
        "gniew",
        "angina",
        "wędkowanie",
        "zły",
        "boleść",
        "animozja",
        "animozja",
        "zniszczyć",
        "unicestwiony",
        "unicestwienie",
        "denerwować",
        "kłopot",
        "denerwujący",
        "unieważnić",
        "unieważnienie",
        "anomalia",
        "anonimowy",
        "antagonizm",
        "antagonista",
        "antagonistyczny",
        "wąglik",
        "antychryst",
        "niechęć",
        "przestarzały",
        "antyspołeczny",
        "antyteza",
        "niepokój",
        "niespokojny",
        "apache",
        "apatyczny",
        "apatia",
        "mszyca",
        "przerażający",
        "zapalenie wyrostka robaczkowego",
        "lęk",
        "lękliwy",
        "asygnowanie",
        "archaiczny",
        "żmudny",
        "kłócić się",
        "argument",
        "rzeczowy",
        "jałowy",
        "zbrojenia",
        "postawienie w stan oskarżenia",
        "zaległości",
        "aresztować",
        "arogancja",
        "arogancki",
        "arsen",
        "podpalenie",
        "artyleria",
        "popiół",
        "zawstydzony",
        "proch",
        "tyłek",
        "atakować",
        "napastnik",
        "morderca",
        "dokonać zamachu",
        "zamach",
        "atak",
        "dupek",
        "zabłąkany",
        "wstrzymujący środek",
        "przytułek",
        "ateizm",
        "miażdżyca",
        "okrutny",
        "okrucieństwo",
        "zanik",
        "atak",
        "napadający",
        "osłabiony",
        "osłabienie",
        "śmiałość",
        "surowy",
        "surowość",
        "autokratyczny",
        "autopsja",
        "lawina",
        "chciwość",
        "mściciel",
        "niechętny",
        "niechęć",
        "uniknąć",
        "unikanie",
        "straszny",
        "nieporadność",
        "krzywo",
        "bełkot",
        "bełkocze",
        "pawian",
        "do tyłu",
        "wstecz",
        "łacha",
        "bakteria",
        "NO TRANSLATION",
        "zły",
        "borsuk",
        "źle",
        "niegodziwość",
        "komornik",
        "przynęta",
        "bela",
        "miedza",
        "NO TRANSLATION",
        "bandyta",
        "zmora",
        "huk",
        "banger",
        "wygnać",
        "wygnany",
        "wygnanie",
        "upadły",
        "bankructwo",
        "banshee",
        "kolec",
        "barbarzyńca",
        "barbarzyński",
        "barbaryzm",
        "szczekać",
        "zabroniony",
        "jałowy",
        "barykada",
        "bariera",
        "bezpodstawny",
        "drań",
        "rzadkie ciasto",
        "poobijany",
        "bateria",
        "bitwa",
        "walczył",
        "pole bitwy",
        "sprośny",
        "bagnetowy",
        "okaziciel",
        "bestia",
        "nieludzki",
        "bicie",
        "zdarzać się",
        "błagać",
        "żebrak",
        "żebranie",
        "potwór",
        "zobowiązany",
        "spóźniony",
        "bagatelizować",
        "wojujący",
        "pas",
        "giętarka",
        "pogrążony w smutku",
        "żałoba",
        "pozbawiony",
        "szał",
        "bestialski",
        "zdradzać",
        "zdrada",
        "strzec się",
        "oszołomiony",
        "stronniczość",
        "stronniczy",
        "sprzeczka",
        "NO TRANSLATION",
        "bigot",
        "zajadły",
        "żółć",
        "biopsja",
        "brzozowy",
        "miejsce urodzenia",
        "suka",
        "gryźć",
        "gorzko",
        "gorycz",
        "dziwaczny",
        "czarny",
        "maczuga",
        "szantaż",
        "czerń",
        "winić",
        "mdłe",
        "bluźnierczy",
        "bluźnierstwo",
        "podmuch",
        "krzykliwy",
        "blather",
        "płomień",
        "posępny",
        "krwawienie",
        "skaza",
        "zwarzyć",
        "zniszczony",
        "ślepy",
        "oślepiony",
        "ślepo",
        "ślepota",
        "pęcherz",
        "nadęty",
        "kropelka",
        "blokada",
        "rozlew krwi",
        "krwiożerczy",
        "krwawy",
        "plama",
        "dmuchacz",
        "wydmuch",
        "blues",
        "urwisko",
        "pomyłka",
        "plama",
        "zamazany",
        "rumieniec",
        "przechwalanie się",
        "bagno",
        "podrobiony",
        "gotować",
        "Płyta montażowa",
        "bomba",
        "bombardować",
        "bombardowanie",
        "zbombardowany",
        "niewola",
        "więzy",
        "gwizd",
        "duda",
        "gorzałka",
        "NO TRANSLATION",
        "nuda",
        "nudny",
        "pożyczający",
        "zawracać głowę",
        "kłopotliwy",
        "Dolny",
        "granica",
        "atak",
        "wołowy",
        "chłopak",
        "bojkot",
        "przechwalać",
        "Brandy",
        "zuchwałość",
        "bijatyka",
        "nachalny",
        "wyłom",
        "awaria",
        "niebezpieczny",
        "NO TRANSLATION",
        "przekupić",
        "przekupstwo",
        "brygada",
        "siarka",
        "jeżyć",
        "burta",
        "burda",
        "zepsuł się",
        "złamany",
        "burdel",
        "siniak",
        "siła",
        "brutalny",
        "brutalność",
        "bydlę",
        "bufet",
        "pluskwa",
        "NO TRANSLATION",
        "bulwiasty",
        "tyran",
        "tyłek",
        "bummer",
        "uciążliwy",
        "biurokracja",
        "biurokrata",
        "włamywacz",
        "włamanie",
        "pogrzeb",
        "pochowany",
        "Burke",
        "spalony",
        "odpadł",
        "rzeźnik",
        "krupon",
        "brzęczał",
        "kabała",
        "kakofonia",
        "cham",
        "zwłoki",
        "klatka szybowa",
        "obliczenie",
        "NO TRANSLATION",
        "połączenia",
        "prowadzenie kampanii",
        "Anuluj",
        "nowotwór",
        "rak",
        "kanibal",
        "kanibalizm",
        "NO TRANSLATION",
        "jeniec",
        "niewola",
        "captor",
        "zdobyć",
        "tusza",
        "rak",
        "kardiomiopatia",
        "niedbalstwo",
        "karykatura",
        "próchnica",
        "rzeź",
        "cielesny",
        "mięsożerny",
        "kartel",
        "walizka",
        "kasetka",
        "kasta",
        "wypadek",
        "zaćma",
        "katastrofa",
        "cewnik",
        "Uwaga",
        "scedować",
        "cmentarz",
        "cenzor",
        "cenzura",
        "cess",
        "zaprzestanie",
        "plewy",
        "otarcia",
        "zmartwienie",
        "wyzwanie",
        "chaos",
        "chaotyczny",
        "szarada",
        "podlegający opłacie",
        "pościg",
        "kara",
        "gawędziarski",
        "tani",
        "oszukać",
        "sernik",
        "szykany",
        "dziecinny",
        "chłodny",
        "chloroform",
        "dławić się",
        "cholera",
        "posiekać",
        "robota",
        "chroniczny",
        "papieros",
        "krzyk",
        "kolidować",
        "zderzenie",
        "pazur",
        "klasztor",
        "zachmurzone",
        "zachmurzenie",
        "kępa",
        "niezdarny",
        "kokaina",
        "przymusić",
        "przymus",
        "trumna",
        "zimno",
        "ozięble",
        "chłód",
        "kolka",
        "zawalić się",
        "kolizja",
        "zmowa",
        "śpiączka",
        "śpiączkowy",
        "walka",
        "bojownik",
        "wojowniczy",
        "zobowiązujący",
        "zamieszanie",
        "komunizm",
        "komunistyczny",
        "zawody",
        "skarżyć się",
        "skarga",
        "skompleksowany",
        "złożoność",
        "komplikować",
        "skomplikowane",
        "powikłanie",
        "kompost",
        "przymus",
        "obowiązkowy",
        "ukryć",
        "ukryty",
        "ukrywanie",
        "zarozumiałość",
        "zarozumiały",
        "wstrząs",
        "potępiać",
        "potępienie",
        "protekcjonalny",
        "łaskawość",
        "wyznanie",
        "ograniczać",
        "ograniczony",
        "uwięzienie",
        "konfiskować",
        "konfiskata",
        "pożar",
        "konflikt",
        "sprzeczny",
        "zawieść",
        "zakłopotany",
        "dezorientować",
        "zamieszanie",
        "przekrwienie",
        "czary",
        "podbój",
        "spiskowiec",
        "konspirować",
        "konsternacja",
        "zaparcie",
        "wymusić",
        "ograniczony",
        "przymus",
        "zakażenie",
        "zaraźliwy",
        "zanieczyścić",
        "zanieczyszczone",
        "zanieczyszczenie",
        "pogarda",
        "podły",
        "pogardliwy",
        "sporny",
        "kontrabanda",
        "zakontraktowany",
        "zaprzeczać",
        "sprzeczność",
        "sprzeczny",
        "przeciwnie",
        "skontrastowane",
        "naruszać",
        "naruszenie przepisów",
        "kontrowersyjny",
        "spór",
        "skazać",
        "przekonanie",
        "kooperacja",
        "Kopiuj",
        "naśladowca",
        "koroner",
        "kapral",
        "zwłoki",
        "korekta",
        "korozja",
        "żrący",
        "skorumpowany",
        "korumpujący",
        "korupcja",
        "kaszel",
        "doradca",
        "pościg",
        "pożądać czegoś",
        "tchórz",
        "tchórzostwo",
        "tchórzliwy",
        "crabby",
        "pęknięcie",
        "pęknięty",
        "Pękanie",
        "skurcz",
        "zbity",
        "korba",
        "zepsuty",
        "bzdury",
        "wypadek",
        "czołgać się",
        "zwariowany",
        "zwariowany",
        "skrzypienie",
        "kreatura",
        "pełzanie",
        "przestępstwo",
        "kryminalista",
        "przestępczość",
        "warować",
        "kaleka",
        "kaleki",
        "kryzys",
        "chrupiący",
        "krytyk",
        "krytyka",
        "krytykować",
        "oszust",
        "krzyż",
        "przyczajony",
        "krzyżowy",
        "ukrzyżowanie",
        "surowy",
        "okrutny",
        "okrutnie",
        "okrucieństwo",
        "kruszenie",
        "schrupać",
        "krucjata",
        "zgnieciony",
        "miażdżący",
        "skorupiasty",
        "płakać",
        "płacz",
        "krypta",
        "rogacz",
        "kukułka",
        "zerwać",
        "wina",
        "winny",
        "winowajca",
        "kult",
        "niewygodny",
        "bańki",
        "kundel",
        "przekleństwo",
        "przeklęty",
        "przeklinanie",
        "pobieżny",
        "nóż",
        "nożownik",
        "tnący",
        "cyjanek",
        "cyklon",
        "torbiel",
        "wirus cytomegalii",
        "spory",
        "demon",
        "stuknięty",
        "sztylet",
        "uszkodzić",
        "odszkodowanie",
        "cholerny",
        "potępienie",
        "cholernie",
        "amortyzator",
        "łupież",
        "elegant",
        "niebezpieczeństwo",
        "niebezpieczny",
        "zaciemniać",
        "ciemnieje",
        "ciemność",
        "przerywana",
        "podły",
        "oszołomiony",
        "dezaktywować",
        "impas",
        "śmiertelnie",
        "głuchy",
        "śmierć",
        "spadek",
        "rozpusta",
        "gruzy",
        "dług",
        "dłużnik",
        "rozkład",
        "zepsute",
        "zmarły",
        "oszustwo",
        "podstępny",
        "oszukać",
        "oszukani",
        "oszukiwanie",
        "oszustwo",
        "zwodniczy",
        "deklinacja",
        "upadek",
        "spadkowy",
        "rozkład",
        "zmniejszać",
        "dekrementacja",
        "zniedołężniały",
        "potępiać",
        "odjąć",
        "zniesławienie",
        "oszczerczy",
        "domyślna",
        "Pokonać",
        "pokonany",
        "wada",
        "NO TRANSLATION",
        "wadliwy",
        "bezbronny",
        "odroczenie",
        "bunt",
        "wyzywający",
        "niedobór",
        "deficyt",
        "siadać",
        "deflacja",
        "deformować",
        "zdeformowany",
        "zniekształcenie",
        "oszukać",
        "zmarły",
        "przeciwstawiać się",
        "degeneracja",
        "zdegenerowany",
        "degradacja",
        "degradować",
        "poniżający",
        "opóźnienie",
        "opóźniony",
        "szkodliwy",
        "usunięcie",
        "przestępczość",
        "przestępca",
        "bredzący",
        "delirium",
        "potop",
        "złudzenie",
        "urojeniowy",
        "żądanie",
        "wymagające",
        "obłąkany",
        "demencja",
        "zgon",
        "zburzyć",
        "rozbiórka",
        "Demon",
        "demoniczny",
        "zdemoralizowany",
        "odmowa",
        "odmówiono",
        "potępiać",
        "wypowiedzenie",
        "zaprzeczać",
        "zaprzeczanie",
        "odszedł",
        "wyjazd",
        "zależność",
        "zależność",
        "opłakany",
        "ubolewać",
        "deportować",
        "deportacja",
        "zdeprawowany",
        "deprawacja",
        "deprecjonować",
        "stracił na wartości",
        "deprecjacja",
        "deprymować",
        "przygnębiony",
        "przygnębiający",
        "depresja",
        "depresyjny",
        "pozbawienie",
        "obłąkany",
        "opuszczony",
        "drwina",
        "derogacja",
        "uwłaczający",
        "profanacja",
        "pustynia",
        "opustoszały",
        "dezercja",
        "odstąpić",
        "spustoszenie",
        "rozpacz",
        "zdesperowany",
        "zdesperowany",
        "podły",
        "NO TRANSLATION",
        "despotyczny",
        "despotyzm",
        "w nędzy",
        "zniszczony",
        "niszczyciel",
        "niszczenie",
        "zniszczenie",
        "destrukcyjny",
        "oderwanie",
        "zatrzymać",
        "aresztowany",
        "aresztowanie",
        "pogarszać się",
        "pogarszony",
        "pogorszenie",
        "brzydzić",
        "detonować",
        "pomniejszać",
        "uszczerbek",
        "szkodliwy",
        "detritus",
        "niszczyć",
        "niszczycielski",
        "dewastacja",
        "diabeł",
        "diabelski",
        "przebiegły",
        "degeneracja",
        "pożerać",
        "diaboliczny",
        "diagnoza",
        "diatryba",
        "dyktator",
        "dyktatorski",
        "dyktatura",
        "NO TRANSLATION",
        "trudności",
        "trudność",
        "błądzić",
        "zniszczony",
        "rozcieńczać",
        "zmniejszać",
        "zmniejszony",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "brud",
        "brudny",
        "inwalidztwo",
        "wyłączyć",
        "niepełnosprawny",
        "zniechęcony",
        "nie zgadzać się",
        "nie zgadzam się",
        "niezgoda",
        "niedozwolone",
        "zawieść",
        "rozczarowany",
        "niezadowalający",
        "rozczarowanie",
        "dezaprobata",
        "potępiać",
        "Odrzucona",
        "krzywy",
        "katastrofa",
        "fatalny",
        "nie dowierzać komuś",
        "odrzuty",
        "rozładować się",
        "dyscyplina",
        "zrzec się",
        "odbarwienie",
        "odbarwione",
        "niewygoda",
        "rozłączyć się",
        "niepowiązany",
        "odłączenie",
        "niezadowolenie",
        "zaprzestać",
        "Nieciągłość",
        "niezgoda",
        "zniechęcać",
        "zniechęcenie",
        "zdyskredytować",
        "dyskryminować",
        "dyskryminacyjny",
        "dyskryminacja",
        "pogarda",
        "choroba",
        "chory",
        "bezcielesny",
        "rozłączenie",
        "oszpecone",
        "hańba",
        "NO TRANSLATION",
        "haniebny",
        "niezadowolony",
        "niesmak",
        "obrzydliwy",
        "zniechęcony",
        "przygnębiające",
        "nieuczciwy",
        "nieuczciwość",
        "hańba",
        "rozczarowanie",
        "dezinformacja",
        "obłudny",
        "rozpadać się",
        "rozpad",
        "bezinteresowny",
        "nie lubić",
        "nielubiane",
        "zwichnięty",
        "ponury",
        "przerażenie",
        "amputacja",
        "zwolnienie",
        "nieposłuszeństwo",
        "nieposłuszny",
        "być nieposłusznym",
        "nieład",
        "nieporządny",
        "zdezorganizowany",
        "ubliżać",
        "ubliżający",
        "różnica",
        "beznamiętny",
        "rozwiać",
        "dyspersja",
        "wypierać",
        "niezadowolony",
        "niezadowolenie",
        "sprzedaż",
        "wywłaszczony",
        "Spierać się",
        "dyskwalifikacja",
        "zdyskwalifikowany",
        "zdyskwalifikować",
        "lekceważenie",
        "pominięte",
        "haniebny",
        "brak szacunku",
        "lekceważący",
        "zakłócenie",
        "niezadowolenie",
        "niezgoda",
        "rozłamowy",
        "niedźwiedzia przysługa",
        "dysydent",
        "rozpuszczenie",
        "dysonans",
        "niechęć",
        "niesmaczne",
        "zniekształcony",
        "zniekształcenie",
        "rozpraszać",
        "roztargniony",
        "rozpraszające",
        "roztargnienie",
        "oszalały",
        "rozpacz",
        "zakłopotany",
        "niepokojący",
        "nieufność",
        "niepokojenie",
        "zaniepokojony",
        "nie używać",
        "nie używany",
        "rozbieżny",
        "zbywany",
        "ogołocenie",
        "rozwód",
        "zawroty głowy",
        "oszołomiony",
        "zadokowany",
        "NO TRANSLATION",
        "chandra",
        "zasiłek",
        "NO TRANSLATION",
        "dominujący",
        "dominacja",
        "osioł",
        "gryzmolić",
        "los",
        "stracony",
        "Dzień Sądu Ostatecznego",
        "wątpić",
        "wątpliwy",
        "wątpienie",
        "natrysk",
        "srogi",
        "upadek",
        "bezbarwny",
        "drenaż",
        "wada",
        "strach",
        "straszny",
        "piekielnie",
        "ponury",
        "picie",
        "brednia",
        "warkot",
        "opadający",
        "Okres suszy",
        "utopić",
        "senność",
        "mordęga",
        "pijany",
        "pijaństwo",
        "wątpliwy",
        "nudny",
        "głupi",
        "manekin",
        "depresja",
        "bury",
        "loch",
        "ofiara oszustwa",
        "dwulicowość",
        "przymus",
        "kurz",
        "skarłowaciały",
        "umierający",
        "czerwonka",
        "trzęsienie ziemi",
        "Podsłuch",
        "edykt",
        "zniewieściały",
        "egoistyczny",
        "skandaliczny",
        "wyrzucać",
        "wyrzucanie",
        "eliminacja",
        "nieuchwytny",
        "wychudzony",
        "NO TRANSLATION",
        "zawstydzić",
        "żenujący",
        "zakłopotanie",
        "sprzeniewierzenie",
        "embolizm",
        "zagmatwany",
        "nagły wypadek",
        "enklawa",
        "wtargnięcie",
        "obciążenie",
        "narazić",
        "zagrożone",
        "endemiczny",
        "wróg",
        "egzekwowanie",
        "enigmatyczny",
        "wrogość",
        "ujarzmiać",
        "zniewolony",
        "niewola",
        "uwikłany",
        "splątanie",
        "wnętrzności",
        "zazdrosny",
        "epidemia",
        "padaczka",
        "wytępić",
        "likwidacja",
        "wymazać",
        "erozja",
        "błądzić",
        "błędny",
        "niekonsekwentny",
        "errata",
        "błędny",
        "błąd",
        "wybuchać",
        "wybuch",
        "zwiększać",
        "unikać",
        "szpiegostwo",
        "zirytowany",
        "eutanazja",
        "ewakuować",
        "ewakuacja",
        "uchylać się",
        "uchylanie się",
        "eksmitować",
        "eksmisja",
        "zło",
        "zaostrzyć",
        "zaostrzenie",
        "wymagający",
        "wyolbrzymiać",
        "przesadny",
        "badanie",
        "rozdrażnienie",
        "wykop",
        "nadmiar",
        "akcyza",
        "wyłączony",
        "nie licząc",
        "wykluczenie",
        "odchody",
        "rozdzierający",
        "pretekst",
        "wykonanie",
        "kat",
        "wydechowy",
        "wyczerpany",
        "wyczerpanie",
        "NO TRANSLATION",
        "wygnanie",
        "egzorcyzm",
        "wygnaniec",
        "usunąć",
        "wydatek",
        "wydatki",
        "wygasać",
        "przedawniony",
        "dopełniający",
        "eksplodować",
        "eksplozja",
        "materiał wybuchowy",
        "narażony",
        "wywłaszczenie",
        "wydalenie",
        "wyniszczać",
        "eksterminacja",
        "wyginąć",
        "gasić",
        "pozasądowe",
        "koniec",
        "wytwarzać",
        "produkcja",
        "blaknąć",
        "kał",
        "w braku",
        "niepowodzenie",
        "półomdlały",
        "niewierny",
        "imitacja",
        "spadek",
        "błędny",
        "błąd",
        "omylny",
        "spadanie",
        "ugór",
        "fałsz",
        "fałszywie",
        "fałszowanie",
        "fałszować",
        "fałsz",
        "wahać się",
        "głód",
        "fanatyk",
        "farsa",
        "farsowy",
        "poszczenie",
        "gruby",
        "fatalny",
        "śmiertelność",
        "los",
        "zmęczenie",
        "zmęczony",
        "tłuszczowy",
        "wina",
        "wadliwy",
        "płowy",
        "strach",
        "straszliwy",
        "ze strachem",
        "obawiając się",
        "gorączkowy",
        "kał",
        "kał",
        "opłata",
        "słaby",
        "udawany",
        "spadł",
        "zbrodniarz",
        "przestępstwo",
        "ferment",
        "srogi",
        "okrucieństwo",
        "wojna",
        "feudalny",
        "feudalizm",
        "gorączkowy",
        "fiasko",
        "bujda",
        "zmienny",
        "fikcyjny",
        "diabeł",
        "dziki",
        "walka",
        "walczący",
        "korsarz",
        "brud",
        "brudny",
        "broń palna",
        "pasuje",
        "wiotki",
        "wiotki",
        "flagi",
        "rażący",
        "płatek",
        "klapka",
        "bębnica",
        "afiszować",
        "wada",
        "pchła",
        "NO TRANSLATION",
        "runo",
        "mięsisty",
        "wzdrygnąć się",
        "biczować",
        "brzdęknięcie",
        "flądra",
        "grypa",
        "fluktuacja",
        "wróg",
        "udaremniony",
        "szaleństwo",
        "oszukać",
        "głupi",
        "głupota",
        "pasza",
        "najazd",
        "zakazać",
        "groźny",
        "siła",
        "wymuszony",
        "siłą",
        "przeczucie czegoś złego",
        "wykluczać",
        "zrzec się",
        "obcy",
        "cudzoziemiec",
        "uprzedzony",
        "utracić",
        "przepadł",
        "przepadek",
        "fałszerstwo",
        "zapomnieć",
        "zapomniany",
        "opuszczony",
        "bezkształtny",
        "cudzołóstwo",
        "opuszczać",
        "opuszczony",
        "faul",
        "pęknięcie",
        "kruchy",
        "słabość",
        "oszalały",
        "oszustwo",
        "oszukańczy",
        "brzemienny",
        "walka",
        "postrzępiony",
        "kapryśny",
        "zamrażanie",
        "szalony",
        "oszalały",
        "szał",
        "denerwować",
        "strach",
        "przestraszyć",
        "przerażony",
        "straszny",
        "lodowaty",
        "frywolny",
        "odmrożenie",
        "spienić",
        "marszczyć brwi",
        "marszcząc brwi",
        "bezowocny",
        "paraliżować",
        "sfrustrowany",
        "udaremnienie",
        "banialuki",
        "zbieg",
        "grzebanie się",
        "opar",
        "wściekły",
        "grzyb",
        "boj",
        "wściekły",
        "furora",
        "Furia",
        "zamieszanie",
        "wybredny",
        "daremny",
        "daremność",
        "dureń",
        "knebel",
        "żółć",
        "szubienica",
        "hazard",
        "hazardzista",
        "hazard",
        "banda",
        "areszt",
        "luka",
        "Śmieci",
        "krzykliwy",
        "garnirunek",
        "blizna",
        "bez tchu",
        "NO TRANSLATION",
        "wychudzony",
        "pan",
        "geriatryczny",
        "upiorny",
        "getto",
        "widmowy",
        "szwargot",
        "lodowaty",
        "blask",
        "rażący",
        "bez zająknienia",
        "mrok",
        "ponury",
        "ponury",
        "nadmiar",
        "obżarstwo",
        "gnom",
        "chochlik",
        "bezbożny",
        "rzeżączka",
        "maź",
        "klin",
        "wąwóz",
        "goryl",
        "krwawy",
        "plotka",
        "wyżłobienie",
        "dna",
        "rząd",
        "chwycić",
        "chwytający",
        "ruszt",
        "tarty",
        "krata",
        "grób",
        "chciwość",
        "chciwy",
        "granat",
        "smutek",
        "skarga",
        "smucić",
        "ciężki",
        "ponury",
        "brud",
        "umorusany",
        "szlifowanie",
        "przerażający",
        "siwy",
        "jęk",
        "NO TRANSLATION",
        "obrzydliwy",
        "groteskowy",
        "uziemiony",
        "bezzasadny",
        "warczeć",
        "warczenie",
        "uraza",
        "niechętnie",
        "makabryczny",
        "gburowaty",
        "narzekać",
        "gderliwy",
        "guerilla",
        "podstęp",
        "gilotyna",
        "wina",
        "winny",
        "przebranie",
        "frajer",
        "łatwowierny",
        "pistolet",
        "wytrysk",
        "żłopie",
        "cygański",
        "wiedźma",
        "mizerny",
        "włochaty",
        "wpół",
        "halucynacja",
        "kantar",
        "postojowy",
        "utrudniać",
        "ścięgno udowe",
        "upośledzenie",
        "wiszące",
        "kat",
        "nękać",
        "zwiastun",
        "utwardzony",
        "twardość",
        "trudność",
        "nierządnica",
        "szkoda",
        "szkodliwy",
        "Bielenie",
        "złupić",
        "szorstkość",
        "haszysz",
        "haszysz",
        "pochopny",
        "nienawidzić",
        "nienawistny",
        "nienawidzić",
        "nienawiść",
        "wyniosły",
        "nawiedzać",
        "nawiedzany",
        "spustoszenie",
        "zaryzykować",
        "niebezpieczny",
        "mgła",
        "bół głowy",
        "mocny",
        "przesłuchanie",
        "pogłoska",
        "karawan",
        "ból serca",
        "zgaga",
        "bez serca",
        "pogański",
        "ciężko",
        "obcas",
        "podnieść",
        "haniebny",
        "piekło",
        "piekielny",
        "bezradny",
        "bezsilność",
        "krwotok",
        "hemoroidy",
        "herezja",
        "heretyk",
        "hermafrodyta",
        "heroina",
        "opryszczka",
        "herpeswirus",
        "wahanie",
        "ukryty",
        "ohydny",
        "przeszkadzanie",
        "przeszkoda",
        "hipis",
        "syk",
        "syczący",
        "trafienie",
        "dotychczas",
        "ul",
        "ochrypły",
        "oszroniony",
        "oszustwo",
        "włóczęga",
        "wieprz",
        "wydrążony",
        "całopalenie",
        "bezdomny",
        "stęskniony za krajem",
        "morderczy",
        "zabójstwo",
        "homoseksualizm",
        "kaptur",
        "haczykowaty",
        "trąbienie",
        "beznadziejny",
        "beznadziejność",
        "horda",
        "okropny",
        "potwornie",
        "okropny",
        "przerażający",
        "przerażony",
        "przerażające",
        "przerażenie",
        "okropności",
        "zakładnik",
        "wrogi",
        "działania wojenne",
        "wrogość",
        "wycie",
        "irytacja",
        "humbug",
        "poniżyć",
        "poniżający",
        "upokorzenie",
        "przeczucie",
        "głodny",
        "Łowca",
        "polowanie",
        "huragan",
        "pośpieszny",
        "ból",
        "bolesny",
        "boli",
        "energiczny człowek",
        "hydra",
        "wodogłowie",
        "szum",
        "hiperbola",
        "hipokryzja",
        "hipokryta",
        "obłudny",
        "histeria",
        "histeryczny",
        "idiotyzm",
        "idiota",
        "idiotyczny",
        "koło pasowe luźne",
        "bałwochwalstwo",
        "ignorancja",
        "nieświadomy",
        "ignorować",
        "chory",
        "nielegalny",
        "nielegalność",
        "nieczytelny",
        "nieślubny",
        "nielegalny",
        "analfabeta",
        "choroba",
        "nielogiczny",
        "iluzja",
        "naśladować",
        "imitacja",
        "niedojrzały",
        "niedojrzałość",
        "niemoralny",
        "niemoralność",
        "osłabiać",
        "osłabienie",
        "nieprzekraczalny",
        "niecierpliwość",
        "Jestem cierpliwy",
        "zakwestionować",
        "oskarżenie",
        "utrudniać",
        "niedoskonałość",
        "niedoskonale",
        "podszywać się",
        "personifikacja",
        "nieubłagany",
        "wplątać",
        "nieuprzejmy",
        "nakładanie",
        "niemożliwy",
        "impotencja",
        "bezsilny",
        "zająć własność",
        "niewykonalny",
        "uwięzić",
        "uwięziony",
        "uwięzienie",
        "niewłaściwość",
        "nieroztropny",
        "zanieczyszczony",
        "zanieczyszczenie",
        "przypisanie",
        "niemożność",
        "niedostępny",
        "niedokładny",
        "bezczynność",
        "bezczynność",
        "NO TRANSLATION",
        "niewystarczający",
        "niedopuszczalny",
        "głupkowaty",
        "nieodpowiedni",
        "niewłaściwy",
        "nieuwaga",
        "niesłyszalny",
        "nieobliczalny",
        "nieudolność",
        "uwięzienie",
        "w razie",
        "zapalający",
        "kadzidło",
        "nieustanny",
        "kazirodztwo",
        "kazirodczy",
        "spopielanie",
        "nawoływać",
        "surowy",
        "niespójny",
        "niekompatybilny",
        "niekompetencja",
        "niekompetentny",
        "niekompletność",
        "niezrozumiały",
        "absurdalny",
        "niekonsekwentny",
        "nieuprzejmy",
        "niezgodność",
        "niewygodny",
        "błędny",
        "nieufny",
        "obwinienie",
        "zmora",
        "ponieść",
        "nieuleczalny",
        "najazd",
        "nieprzyzwoity",
        "niezdecydowanie",
        "niezdecydowany",
        "nie do obrony",
        "wynagradzać",
        "umowa obustronna",
        "nieokreślony",
        "oskarżać",
        "akt oskarżenia",
        "obojętność",
        "biedny",
        "oburzony",
        "oburzenie",
        "niewyraźny",
        "indoktrynacja",
        "leniwy",
        "nieskuteczny",
        "nieudolny",
        "nieskuteczność",
        "nieskuteczny",
        "niedorzeczny",
        "niestosowność",
        "nierówność",
        "niesprawiedliwy",
        "obojętny",
        "niewybaczalny",
        "NO TRANSLATION",
        "niedoświadczony",
        "niewytłumaczalny",
        "niesławny",
        "hańba",
        "dzieciobójca",
        "infantylny",
        "zawał",
        "infekować",
        "infekcja",
        "zakaźny",
        "gorszy",
        "niższość",
        "piekło",
        "bezpłodność",
        "infestacja",
        "niewierny",
        "niewierność",
        "niedołężny",
        "niemoc",
        "zapalenie",
        "nadmuchany",
        "inflacja",
        "zadać",
        "zadanie",
        "grypa",
        "informator",
        "naruszenie",
        "nieczęsto",
        "naruszenie",
        "hamować",
        "nieprzyjazny",
        "nieludzki",
        "nieludzkość",
        "wrogi",
        "niesprawiedliwość",
        "nakaz",
        "zranić",
        "ranny",
        "szkodliwy",
        "zranienie",
        "niesprawiedliwość",
        "więzień",
        "nieczynny",
        "szalony",
        "niepoczytalność",
        "niepewny",
        "niepewność",
        "podstępny",
        "znikomość",
        "nieistotny",
        "mdły",
        "bezczelny",
        "niewypłacalność",
        "niewypłacalny",
        "niestabilność",
        "podżegać",
        "podżeganie",
        "niewydolność",
        "niewystarczający",
        "niewystarczająco",
        "zniewaga",
        "obraźliwy",
        "powstaniec",
        "nie do pokonania",
        "insurekcja",
        "pochować",
        "zakaz",
        "ingerencja",
        "pogrzebanie zwłok",
        "przerwać",
        "przerwany",
        "bez testamentu",
        "zastraszyć",
        "zastraszenie",
        "nie do zniesienia",
        "nietolerancja",
        "nietolerancyjny",
        "odurzony",
        "trudny",
        "intryga",
        "intruz",
        "wtargnięcie",
        "natrętny",
        "najechać",
        "najeźdźca",
        "unieważnić",
        "unieważnienie",
        "nieważność",
        "inwazja",
        "mimowolny",
        "inwolucja",
        "zirytowany",
        "NO TRANSLATION",
        "okowy",
        "irracjonalny",
        "irracjonalność",
        "nie do pogodzenia",
        "nieregularny",
        "nieprawidłowość",
        "bez znaczenia",
        "nie do naprawienia",
        "nieodpowiedzialny",
        "lekceważący",
        "nieodwołalny",
        "drażliwość",
        "drażliwy",
        "irytujący",
        "podrażnienie",
        "odosobniony",
        "izolacja",
        "paplanie",
        "więzienie",
        "żargon",
        "rażący",
        "żółtaczka",
        "zazdrosny",
        "zazdrość",
        "narazić",
        "niebezpieczeństwo",
        "Jan",
        "żart",
        "NO TRANSLATION",
        "mieszanina",
        "dżonka",
        "junta",
        "nieletni",
        "kern",
        "kopnięcie",
        "porwać kogoś",
        "zabić",
        "zabicie",
        "latawiec",
        "podzwonne",
        "wiązane",
        "pracowali",
        "pracochłonny",
        "labirynt",
        "brak",
        "brakuje",
        "Lśniący",
        "obciążony",
        "opóźnienie",
        "otulina",
        "leże",
        "lament",
        "osuwisko",
        "ospały",
        "pokutować",
        "słaby",
        "pomyłka",
        "kradzież",
        "bicz",
        "późno",
        "spóźnienie",
        "utajony",
        "latryny",
        "śmieszny",
        "lawa",
        "bezprawie",
        "pozew sądowy",
        "prawnik",
        "niedbały",
        "przeczyszczający",
        "leniwy",
        "nieszczelność",
        "wyciek",
        "nieszczelny",
        "pozostawiać",
        "pijawka",
        "pijawki",
        "NO TRANSLATION",
        "cytrynowy",
        "trąd",
        "lesbijka",
        "zmniejszać",
        "pomniejszy",
        "śmiertelny",
        "letarg",
        "białaczka",
        "nałożyć",
        "sprośny",
        "łączność",
        "kłamca",
        "oszczerstwo",
        "lizać",
        "kłamstwo",
        "bez życia",
        "ograniczony",
        "utykać",
        "szarpie",
        "trunek",
        "apatyczny",
        "sporny",
        "procesować się",
        "spór",
        "sporny",
        "śmieci",
        "wściekły",
        "Bochenek",
        "próżniak",
        "NO TRANSLATION",
        "brzydzić",
        "odraza",
        "odrażający",
        "lobbysta",
        "NO TRANSLATION",
        "szarańcza",
        "wysoki",
        "samotność",
        "samotny",
        "samotny",
        "loo",
        "warsztat tkacki",
        "gbur",
        "szalony",
        "łup",
        "stracić",
        "przegrywający",
        "utrata",
        "Stracony",
        "głośność",
        "hol",
        "wesz",
        "niższy",
        "opuszczenie",
        "najniższy",
        "niziny",
        "pokorny",
        "śmieszny",
        "niezdarny",
        "guzek",
        "grudkowaty",
        "obłęd",
        "wariat",
        "przechył",
        "wabik",
        "ponury",
        "przyczaić się",
        "przyczajony",
        "bujny",
        "żądza",
        "zmysłowy",
        "kłamstwo",
        "zlinczować",
        "Buzdygan",
        "szalony",
        "szaleć",
        "szaleniec",
        "szaleństwo",
        "mafia",
        "czerw",
        "prowizoryczny",
        "choroba",
        "złe samopoczucie",
        "malaria",
        "wrogi",
        "malfeasance",
        "zniekształcenie",
        "złośliwość",
        "złośliwy",
        "złośliwy",
        "złośliwość",
        "złośliwy",
        "zaniedbanie",
        "mandamus",
        "NO TRANSLATION",
        "magiel",
        "mania",
        "maniak",
        "maniakalny",
        "manipulować",
        "manipulacja",
        "zabójstwo",
        "nawóz",
        "zniszczyć",
        "margines",
        "kasztanowaty",
        "Martingale",
        "męczennik",
        "męczeństwo",
        "masochizm",
        "masakra",
        "materializm",
        "materialista",
        "meandrujący",
        "bez znaczenia",
        "odra",
        "wtrącić się",
        "przeciętny",
        "przeciętność",
        "melancholijny",
        "melancholia",
        "bijatyka",
        "melodramat",
        "topnienie",
        "groźba",
        "groźny",
        "służebny",
        "najemnik",
        "bezlitosny",
        "bałagan",
        "niechlujny",
        "przerzut",
        "metanol",
        "pleśń",
        "milicja",
        "mimika",
        "zminimalizować",
        "minimum",
        "mniejszość",
        "NO TRANSLATION",
        "sprawka",
        "poronienie",
        "psota",
        "złośliwy",
        "nieporozumienie",
        "złe prowadzenie się",
        "nieszczęśliwy",
        "marnie",
        "nieszczęście",
        "nieszczęście",
        "błędne",
        "nieszczęście",
        "mylna interpretacja",
        "wprowadzić w błąd",
        "zwodniczy",
        "złe kierownictwo",
        "niedopasowanie",
        "błędna nazwa",
        "zapodziać",
        "w niewłaściwym miejscu",
        "zakłamać",
        "przekręcanie",
        "fałszywie przedstawiane",
        "brakujący",
        "nieprawidłowość",
        "błąd",
        "błędny",
        "kochanka",
        "NO TRANSLATION",
        "źle zrozumieć",
        "nieporozumienie",
        "nadużywanie",
        "grosz",
        "tłum",
        "kpina",
        "kpiąco",
        "molestowanie",
        "monochromia",
        "monopolista",
        "monsun",
        "potwór",
        "potworność",
        "nastrojowy",
        "sporny",
        "chorobowy",
        "zachorowalność",
        "kostnica",
        "konający",
        "idiota",
        "kretyński",
        "kąsek",
        "śmiertelny",
        "śmiertelność",
        "umartwienie",
        "kostnica",
        "komar",
        "opłakiwać",
        "smutny",
        "żałoba",
        "błoto",
        "błoto",
        "zamęt",
        "zmącony",
        "zmącić",
        "mufka",
        "muł",
        "milczący",
        "bełkot",
        "świnka",
        "morderstwo",
        "morderca",
        "morderczy",
        "mroczny",
        "NO TRANSLATION",
        "stęchły",
        "mutant",
        "okaleczony",
        "okaleczenie",
        "bunt",
        "NO TRANSLATION",
        "pysk",
        "krótkowzroczność",
        "złapać",
        "nadir",
        "NO TRANSLATION",
        "naiwny",
        "bezimienny",
        "pieluszka",
        "narkotyczny",
        "paskudny",
        "niegrzeczny",
        "nudności",
        "nudny",
        "NO TRANSLATION",
        "potrzebny",
        "potrzebujący",
        "nikczemny",
        "negacja",
        "negatywny",
        "zaniedbanie",
        "zaniedbany",
        "zaniedbanie",
        "zaniedbanie",
        "niedbały",
        "NO TRANSLATION",
        "Murzyn",
        "nepotyzm",
        "nerwowy",
        "dolny",
        "pokrzywa",
        "nerwoból",
        "nerwica",
        "nerwicowy",
        "nikotyna",
        "czarnuch",
        "koszmar",
        "nihilizm",
        "hałas",
        "głośny",
        "NO TRANSLATION",
        "nonsens",
        "bezsensowny",
        "pętla",
        "nicość",
        "szkodliwy",
        "kłopot",
        "NO TRANSLATION",
        "unieważnić",
        "zdrętwiały",
        "drętwienie",
        "NO TRANSLATION",
        "niedołęga",
        "otyły",
        "otyłość",
        "obi",
        "obit",
        "pośmiertny",
        "sprzeciw",
        "niewłaściwy",
        "zobowiązać",
        "dłużnik",
        "wymazać",
        "zatarte",
        "obliteracja",
        "zapomnienie",
        "nieprzyjemny",
        "nieprzyzwoity",
        "nieprzyzwoitość",
        "zapomnienie",
        "przeszkoda",
        "uparty",
        "blokować",
        "przeszkoda",
        "zatykający",
        "rozwarty",
        "okultystyczny",
        "kuriozum",
        "wstrętny",
        "zapach",
        "obrazić",
        "obrażony",
        "przestępca",
        "wykroczenie",
        "ofensywa",
        "bezceremonialny",
        "otwarte morze",
        "ogr",
        "węchowy",
        "oligarchia",
        "omen",
        "złowieszczy",
        "pomijać",
        "uciążliwy",
        "odpowiedzialność",
        "muł",
        "nieprzezroczysty",
        "operowy",
        "opiat",
        "uparty",
        "opium",
        "przeciwnik",
        "sprzeciwiać się",
        "przeciwny",
        "sprzeciw",
        "uciskać",
        "ucisk",
        "uciążliwy",
        "prześladowca",
        "orc",
        "ciężka próba",
        "artyleria",
        "sierota",
        "pozornie",
        "wyrugować",
        "wyrzutek",
        "wrzask",
        "przybudówka",
        "obcy",
        "banita",
        "skandal",
        "owacja",
        "apodyktyczny",
        "przeciążać",
        "pochmurny",
        "przedobrzyć",
        "przedawkować",
        "zaległy",
        "przeszacowane",
        "przelewowy",
        "zarośnięty",
        "przeciążać",
        "nadpłacony",
        "pokonać",
        "przytłaczający",
        "zbyt drogie",
        "przeoczenie",
        "obalenie",
        "obalić",
        "zasypać",
        "przytłoczony",
        "należny",
        "utlenianie",
        "ból",
        "bolesny",
        "bolesny",
        "dokuczliwie",
        "trud",
        "porażenie",
        "pandemiczny",
        "NO TRANSLATION",
        "panika",
        "paraliż",
        "sparaliżowany",
        "paranoja",
        "pasożyt",
        "NO TRANSLATION",
        "papuga",
        "skąpy",
        "partyzant",
        "NO TRANSLATION",
        "bierny",
        "pasywność",
        "łata",
        "żałosne",
        "protekcjonalny",
        "NO TRANSLATION",
        "niedostatek",
        "żebrak",
        "pionek",
        "zwrot",
        "Zapłata",
        "osobliwości",
        "pieszy",
        "karny",
        "rzut karny",
        "penetracja",
        "zakład karny",
        "zatracenie",
        "niebezpieczeństwo",
        "niebezpieczny",
        "zginąć",
        "łatwo psujący się",
        "zginął",
        "ginąc",
        "krzywoprzysięstwo",
        "zgubny",
        "sprawca",
        "uwiecznienie",
        "zakłopotany",
        "zakłopotanie",
        "prześladować kogoś",
        "prześladowanie",
        "perturbacja",
        "krztuśca",
        "przewrotny",
        "perwersja",
        "zboczeniec",
        "zdemoralizowany",
        "pesymizm",
        "pesymista",
        "szkodnik",
        "zaraza",
        "zwierzę domowe",
        "drobny",
        "Fantom",
        "flegma",
        "fałszywe",
        "szpica",
        "pikietowanie",
        "marynata",
        "świnia",
        "Gołąb",
        "hemoroidy",
        "plądrowanie",
        "sutener",
        "pryszcz",
        "sosna",
        "wałek zębaty",
        "pika",
        "piractwo",
        "pirat",
        "pistolet",
        "pułapka",
        "plagiat",
        "plaga",
        "powód",
        "platerowany",
        "gracz",
        "zarzut",
        "sytuacja",
        "plodding",
        "pion",
        "grabież",
        "pogrążać",
        "zapalenie płuc",
        "kłusownictwo",
        "bezcelowy",
        "zatruć",
        "zatrute",
        "zatrucie",
        "trujący",
        "szturchać",
        "polemiczny",
        "paraliż dziecięcy",
        "zanieczyszczać",
        "skażenie",
        "poligamia",
        "przepych",
        "pompatyczny",
        "ciężki",
        "słabo",
        "Muzyka pop",
        "jeżozwierz",
        "porno",
        "porno",
        "pornograficzny",
        "pornografia",
        "poza",
        "opętany",
        "posiadanie",
        "pośmiertny",
        "odroczenie",
        "funt",
        "ubóstwo",
        "bezsilny",
        "wybryk",
        "niepewny",
        "obręb",
        "drapieżny",
        "kłopotliwe położenie",
        "ciąża",
        "uprzedzenie",
        "uprzedzony",
        "szkodliwy",
        "dokonany z premedytacją",
        "nacisk",
        "arogancki",
        "stwarzać pozory",
        "fałszywy",
        "udawać",
        "udawanie",
        "pretencje",
        "zapobiegawczy",
        "zdobycz",
        "ukłucie",
        "kolczasty",
        "więzienie",
        "więzień",
        "wtajemniczony",
        "problem",
        "ociągać się",
        "kunktatorstwo",
        "bezcześcić",
        "bluźnierstwo",
        "obfitość",
        "zabroniony",
        "zakaz",
        "przedłużać",
        "bezładny",
        "propaganda",
        "zaskarżyć",
        "oskarżenie",
        "prostytutka",
        "prostytucja",
        "prowokacja",
        "irytujący",
        "wyważać",
        "wścibstwo",
        "psychoza",
        "publicysta",
        "podpuchnięte",
        "stempel",
        "ostry",
        "karać",
        "ukarany",
        "karanie",
        "kara",
        "karny",
        "czyściec",
        "oczyścić",
        "ropa",
        "Kwak",
        "bagno",
        "Przepiórka",
        "kłopot",
        "sprzeczka",
        "stłumić",
        "stłumić",
        "wątpliwy",
        "rtęć",
        "porzucić",
        "kołczan",
        "drżenie",
        "kartkówka",
        "motłoch",
        "wściekły",
        "wścieklizna",
        "stojak",
        "rakieta",
        "promieniowanie",
        "radioaktywny",
        "radon",
        "wściekłość",
        "wściekły",
        "łachmany",
        "nalot",
        "szyna",
        "Baran",
        "pnący",
        "szał",
        "zjełczały",
        "okup",
        "rzepak",
        "drapieżniki",
        "szelma",
        "wysypka",
        "szczur",
        "ocena",
        "ochrypły",
        "wygłodniały",
        "bredzenie",
        "reakcyjny",
        "tylny",
        "Buntownik",
        "nagana",
        "powstrzymać",
        "oporny",
        "recesja",
        "recydywa",
        "lekkomyślny",
        "lekkomyślność",
        "zbędny",
        "odpływ",
        "oporny",
        "odmowa",
        "odrzucać",
        "odmówił",
        "regres",
        "regresja",
        "żal",
        "godny pożałowania",
        "żałować",
        "żałować",
        "regulacyjne",
        "wodza",
        "odrzucać",
        "odrzucony",
        "odmowa",
        "odrzuca",
        "recydywa",
        "relegacja",
        "porzucić",
        "niechętny",
        "tymczasowo",
        "naprawczy",
        "niedbały",
        "wyrzuty sumienia",
        "usuwanie",
        "usunąć",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "renegat",
        "zrzec się",
        "zrzeczenie się",
        "NO TRANSLATION",
        "odpychający",
        "odpychanie",
        "stłumić",
        "represja",
        "nagana",
        "przedruk",
        "akcja odwetowa",
        "zarzut",
        "republika",
        "odrzucenie",
        "odpychanie",
        "odwołać",
        "anulowanie",
        "oburzać się",
        "urażony",
        "uraza",
        "rezygnować",
        "rezygnacja",
        "zrezygnowany",
        "opierać się",
        "odporność",
        "odporny",
        "oporowy",
        "powstrzymać się",
        "ograniczać",
        "ograniczenie",
        "ograniczający",
        "zemścić się",
        "odwet",
        "odwetowy",
        "opóźniać",
        "opóźnienie",
        "małomówny",
        "retorta",
        "wycofać",
        "wycofanie",
        "obwarowanie",
        "zemsta",
        "wsteczny",
        "zemsta",
        "odwrócenie",
        "unieważnienie",
        "unieważnić",
        "bunt",
        "oburzający",
        "rewolwer",
        "wstręt",
        "reumatyzm",
        "kulawy",
        "podziurawiony",
        "kpiny",
        "śmieszny",
        "rozpowszechniony",
        "karabin",
        "strzelanina",
        "sztywny",
        "sztywność",
        "rygor",
        "rygorystyczny",
        "dzwonnik",
        "zamieszki",
        "rozbrykany",
        "ryzyko",
        "ryzykowny",
        "rywalizacja",
        "obrabować",
        "bandyta",
        "rozbój",
        "łobuz",
        "wieża",
        "gnić",
        "gnić",
        "chropowatość",
        "NO TRANSLATION",
        "rząd",
        "hałaśliwy",
        "śmieci",
        "gruz",
        "żałować",
        "wzburzyć",
        "chropowaty",
        "ruina",
        "zrujnowany",
        "rujnujący",
        "plotka",
        "uciec",
        "pęknięcie",
        "NO TRANSLATION",
        "rdza",
        "zardzewiały",
        "bezwzględny",
        "NO TRANSLATION",
        "sabotaż",
        "ofiary",
        "niestety",
        "smutek",
        "zwis",
        "sok roślinny",
        "sarkazm",
        "mięsak",
        "sardoniczny",
        "szatański",
        "nasycony",
        "brutalny",
        "dzikość",
        "parch",
        "szafot",
        "skalpel",
        "łuskowaty",
        "skandal",
        "skandaliczny",
        "ubogi",
        "kozioł ofiarny",
        "blizna",
        "deficytowy",
        "ledwie",
        "niedostatek",
        "przestraszyć",
        "padlinożerca",
        "schemat",
        "schizma",
        "schizofrenia",
        "ischias",
        "szydzić",
        "nakrzyczeć",
        "besztanie",
        "upalny",
        "pogarda",
        "Skorpion",
        "Szkocka",
        "łajdak",
        "biczować",
        "mieszanie",
        "trzęsawka",
        "krzyk",
        "krzyczeć",
        "pisk",
        "pijany",
        "bójka",
        "zarośla",
        "lustrować",
        "badanie",
        "szumowiny",
        "przypalić",
        "secesja",
        "odosobniony",
        "NO TRANSLATION",
        "wydzielanie",
        "skryty",
        "sekciarski",
        "bunt",
        "uwieść",
        "uwodzenie",
        "segregować",
        "posegregowane",
        "chwycić",
        "samolubny",
        "egoizm",
        "starczy",
        "bezsensowny",
        "zdanie",
        "separatystyczny",
        "posocznica",
        "septyczny",
        "sekwestr",
        "spokojny",
        "wąż",
        "sługa",
        "obsługiwać",
        "służalczy",
        "niewola",
        "wpadka",
        "zerwać",
        "ścieki",
        "kanalizacja",
        "brudny",
        "buda",
        "jarzmo",
        "zacieniony",
        "drżący",
        "chwiejny",
        "pozorny",
        "pobojowisko",
        "wstyd",
        "haniebny",
        "bezwstydny",
        "Szanghaj",
        "rekin",
        "roztrzaskać",
        "roztrzaskany",
        "budka",
        "muszla",
        "odłożone",
        "Wrak statku",
        "gówno",
        "dreszcz",
        "zaszokować",
        "buble",
        "strzelać",
        "strzelanie",
        "kradzież sklepowa",
        "niedobór",
        "niedociągnięcie",
        "strzał",
        "pchnięcie",
        "efektowny",
        "wrzask",
        "przenikliwy",
        "kurczyć się",
        "skurczył się",
        "dreszcz",
        "unikać",
        "chory",
        "obrzydliwy",
        "chorowity",
        "choroba",
        "głupi",
        "NO TRANSLATION",
        "grzeszny",
        "złowrogi",
        "grzesznik",
        "grzesząc",
        "syrena",
        "maminsynek",
        "sceptyczny",
        "szkicowy",
        "przekrzywiony",
        "poślizg",
        "pominąć",
        "potyczka",
        "luźny",
        "żużel",
        "zatrzasnąć",
        "oszczerstwo",
        "oszczerczy",
        "policzkować",
        "ubój",
        "rzeźnia",
        "ubój",
        "niewolnik",
        "niewolnictwo",
        "zabić",
        "pogromca",
        "śnieg z deszczem",
        "śluzowaty",
        "poroniony płód",
        "poślizg",
        "NO TRANSLATION",
        "niechlujny",
        "lenistwo",
        "ciamajda",
        "bagno",
        "powolność",
        "osad",
        "ślimak",
        "powolny",
        "slums",
        "kryzys",
        "łuk",
        "breja",
        "chlapa",
        "chytry",
        "zadatki",
        "mały",
        "rozbić",
        "rozbity",
        "liźnięcie",
        "zapach",
        "pachnący",
        "uśmiech",
        "porazić",
        "palący",
        "udusić",
        "plama",
        "kołtuński",
        "przemycać",
        "przemytnik",
        "przemycanie",
        "świństwa",
        "szkopuł",
        "zaczepki",
        "wąż",
        "sidła",
        "warczenie",
        "warczenie",
        "skradać się",
        "skradanie się",
        "szydzić",
        "kichać",
        "obłudny",
        "snob",
        "moczyć",
        "NO TRANSLATION",
        "socjalista",
        "gleba",
        "zabrudzony",
        "somatyczny",
        "ponury",
        "sadza",
        "czary",
        "brudny",
        "ból",
        "bardzo",
        "ból",
        "smutek",
        "smutny",
        "NO TRANSLATION",
        "bezduszny",
        "bratnia dusza",
        "kwaśny",
        "zbić",
        "skurcz",
        "sprzeczka",
        "włócznia",
        "plamka",
        "widmo",
        "widmowy",
        "spekulacja",
        "wydany",
        "stara panna",
        "złość",
        "złośliwy",
        "drzazga",
        "rozdzielać",
        "rozsadzający w ułamku sekundy",
        "zepsuć",
        "spojler",
        "przemówił",
        "gąbka",
        "zjawa",
        "zwichnięcie",
        "hulanka",
        "krasnoludek",
        "fałszywy",
        "szkwał",
        "skwater",
        "wrażliwy",
        "chlupotać",
        "skręcać się",
        "zasztyletować",
        "oszałamiający",
        "zastały",
        "plama",
        "nieświeży",
        "łodyga",
        "dystans",
        "zastój",
        "gapiowski",
        "sztywny",
        "przestraszyć",
        "głód",
        "zagłodzony",
        "głodujący",
        "nieruchomy",
        "klepka",
        "kraść",
        "kradzież",
        "ukradkowy",
        "stereotyp",
        "stereotypowy",
        "jałowy",
        "sterylność",
        "rufa",
        "sztywny",
        "sztywność",
        "zdusić",
        "stłumiony",
        "piętno",
        "poroniony",
        "Żądło",
        "kłujący",
        "skąpy",
        "smród",
        "śmierdzący",
        "skąpić",
        "dyby",
        "skradziony",
        "kamień",
        "naćpany",
        "taborety",
        "zatrzymanie",
        "burza",
        "burzliwy",
        "napięty",
        "cieśnina",
        "na mieliźnie",
        "nieznajomy",
        "udusić",
        "zabłąkany",
        "naprężenie",
        "walka",
        "strajk",
        "rozebrać się",
        "naszywka",
        "obnażony",
        "uderzenie",
        "borykać się",
        "rozpora",
        "nadąsany",
        "potknąć się",
        "oszołomiony",
        "skarłowaciały",
        "głupi",
        "głupota",
        "stupor",
        "chlew",
        "pokonać",
        "Przedmiot",
        "poddany",
        "uległość",
        "ujarzmienie",
        "podrzędny",
        "wezwanie sądowe",
        "osiadanie",
        "subsydium",
        "istnieć",
        "odejmować",
        "obalenie",
        "wywrotowy",
        "obalić",
        "ulec",
        "ssać",
        "przyssawka",
        "pozwać",
        "ponieść",
        "poszkodowany",
        "cierpienie",
        "duszący",
        "uduszenie",
        "samobójczy",
        "samobójstwo",
        "ponury",
        "wezwanie",
        "zatopiony",
        "powierzchowny",
        "zbędny",
        "przesądny",
        "stłumić",
        "tłumienie",
        "dopłata",
        "gburowaty",
        "poddanie się",
        "poddanie się",
        "podatny",
        "posądzać",
        "zawieszenie",
        "podejrzenie",
        "podejrzany",
        "wymaz",
        "bagno",
        "bagienny",
        "swastyka",
        "obrzęk",
        "haust",
        "wieprz",
        "spuchnięty",
        "objaw",
        "omdlenie",
        "tabu",
        "skaza",
        "NO TRANSLATION",
        "zaplątany",
        "opieszałość",
        "leniwy",
        "taryfa",
        "plamić",
        "smolisty",
        "bez smaku",
        "kpina",
        "podatek",
        "droczyć się",
        "dokuczanie",
        "nudny",
        "NO TRANSLATION",
        "nawałnica",
        "pokusa",
        "kamienica",
        "terminal",
        "zakończenie",
        "bielec",
        "straszny",
        "terror",
        "terroryzm",
        "terrorysta",
        "terroryzować",
        "tężec",
        "pęta",
        "kradzież",
        "teizm",
        "teokratyczny",
        "złodziej",
        "spragniony",
        "cierń",
        "drażliwy",
        "bezmyślny",
        "prać",
        "zagrożenie",
        "grozić",
        "groźny",
        "namłócić",
        "pulsować",
        "przepustnica",
        "bandyta",
        "uderzenie",
        "grzmiący",
        "udaremniać",
        "sprzeczka",
        "nieśmiały",
        "nieśmiałość",
        "nietrzeźwy",
        "tyrada",
        "zmęczony",
        "zmęczenie",
        "nieznośny",
        "cycek",
        "ropucha",
        "tytoń",
        "toaleta",
        "matnia",
        "tolerować",
        "ból zęba",
        "dręczyć",
        "rozdarty",
        "torpeda",
        "skwarny",
        "delikt",
        "tortury",
        "torturować",
        "wzruszony",
        "drażliwy",
        "twardy",
        "toksyczny",
        "toksyna",
        "tragedia",
        "tragiczny",
        "zdrajca",
        "Tramp",
        "trans",
        "przestępstwo",
        "parada",
        "majdan",
        "śmieci",
        "kiczowaty",
        "traumatyczny",
        "NO TRANSLATION",
        "parodia",
        "zdradziecki",
        "zdrada",
        "zdrada",
        "drżenie",
        "drżenie",
        "drżenie",
        "wykroczenie",
        "męka",
        "trybunał",
        "sztuczka",
        "naciągnięcie",
        "drobiazg",
        "dreptanie",
        "Troll",
        "kłopotliwy",
        "trąbka",
        "upadek",
        "guz",
        "guz",
        "zgiełk",
        "zgiełkliwy",
        "turbulencja",
        "burzliwy",
        "zamieszanie",
        "skurcz",
        "tajfun",
        "despotyczny",
        "tyrania",
        "tyran",
        "brzydota",
        "brzydki",
        "wrzód",
        "ukryty",
        "ultimatum",
        "niezdolny",
        "gorszący",
        "niezrozumiały",
        "niezatwierdzone",
        "nieżonaty",
        "nieosiągalny",
        "nieładny",
        "nieautoryzowany",
        "nieunikniony",
        "nieświadomy",
        "nie do zniesienia",
        "niewiara",
        "nie do wiary",
        "przyszły",
        "niesamowity",
        "obojętny",
        "niepewny",
        "niezmienny",
        "nieczysty",
        "niewygodny",
        "horrendalny",
        "nieprzytomny",
        "niekonstytucyjny",
        "niepowstrzymany",
        "niekontrolowany",
        "niezdecydowany",
        "podkopany",
        "niedopłacone",
        "drobny",
        "niepożądany",
        "niepożądane",
        "Cofnij",
        "niepokój",
        "niespokojny",
        "niewykształcony",
        "bezrobotny",
        "nierówny",
        "nierówny",
        "niewyjaśnione",
        "niesprawiedliwy",
        "niesprawiedliwość",
        "niewierny",
        "niekorzystny",
        "niedokończony",
        "pamiętliwy",
        "niefortunny",
        "nieprzyjazny",
        "niespełnione",
        "nieumeblowany",
        "bezbożny",
        "niewdzięczny",
        "nieszczęście",
        "nieszczęśliwy",
        "niezdrowy",
        "bezbożny",
        "nieważny",
        "rozczarowany",
        "nieulepszony",
        "niedoinformowany",
        "niewtajemniczony",
        "banalny",
        "niezrozumiały",
        "niechcący",
        "niezainteresowany",
        "nieinteresujący",
        "niesprawiedliwy",
        "nieuzasadniony",
        "nie usprawiedliwiony",
        "niedobry",
        "nieznany",
        "bezprawny",
        "nielicencjonowany",
        "nieszczęśliwy",
        "krnąbrny",
        "nienaturalny",
        "nieoficjalny",
        "nie zapłacony",
        "nieprzyjemny",
        "niepopularny",
        "nieobliczalny",
        "nieprzygotowany",
        "nieproduktywny",
        "nierentowny",
        "bezbronny",
        "niepublikowane",
        "niewiarygodne",
        "nie wynagrodzony",
        "niesforny",
        "niebezpieczny",
        "niedostateczny",
        "niezadowolony",
        "niesmaczny",
        "bez skrupułów",
        "zaburzony",
        "brzydki",
        "niewyszukany",
        "niewypowiedziany",
        "nietrwały",
        "nieudany",
        "nieodpowiedni",
        "unsung",
        "nieobsługiwane",
        "niezrównoważony",
        "niesympatyczny",
        "nieokiełznany",
        "nie do obrony",
        "nie do pomyślenia",
        "nieporządny",
        "przedwcześnie",
        "nieuprawny",
        "niewypowiedziany",
        "przewrotny",
        "niedoświadczony",
        "nieprawdziwy",
        "niegodny zaufania",
        "bezpodstawny",
        "nieumyte",
        "niepożądany",
        "chory",
        "niechęć",
        "niemądry",
        "niezamierzony",
        "niegodny",
        "nieustępliwy",
        "przewrót",
        "powstanie",
        "wrzawa",
        "zdenerwowany",
        "urwis",
        "pilne",
        "bezużyteczny",
        "uzurpować",
        "uzurpator",
        "lichwa",
        "luka",
        "bezproblemowy",
        "niejasny",
        "brak precyzji",
        "na próżno",
        "wampir",
        "zniknął",
        "próżność",
        "ospa wietrzna",
        "żylaki",
        "wegetatywny",
        "gwałtowny",
        "wendeta",
        "zemsta",
        "mściwy",
        "jad",
        "jadowity",
        "gadatliwość",
        "skraj",
        "robactwo",
        "przeciw",
        "zawrót głowy",
        "weto",
        "wice",
        "złośliwy",
        "ofiara",
        "represjonowany",
        "czarny charakter",
        "nikczemny",
        "mściwy",
        "naruszenie",
        "przemoc",
        "gwałtowny",
        "gwałtownie",
        "żmija",
        "zjadliwość",
        "wirus",
        "wizytacja",
        "lisica",
        "zmienność",
        "wulkan",
        "wymioty",
        "wiara w czary",
        "wulgarny",
        "wulgarność",
        "wrażliwość",
        "sęp",
        "wafel",
        "zawodzenie",
        "czekać",
        "tarzać się",
        "NO TRANSLATION",
        "słabnąć",
        "brakujący",
        "wojna",
        "opiekun",
        "towar",
        "działania wojenne",
        "wojowniczy",
        "ostrzec",
        "osnowa",
        "wichrowaty",
        "brodawka",
        "marnotrawstwo",
        "zmarnowany",
        "rozrzutny",
        "zmarnowanie",
        "wodnisty",
        "chwiać się",
        "osłabiony",
        "słabo",
        "słabość",
        "nosić",
        "zmęczony",
        "zmęczenie",
        "zmęczony",
        "chwasty",
        "płakać",
        "dziwne",
        "dziwak",
        "NO TRANSLATION",
        "dziewucha",
        "walnięcie",
        "kaprys",
        "skomleć",
        "bat",
        "trąba powietrzna",
        "Whisky",
        "kurwa",
        "niegodziwy",
        "niegodziwość",
        "dziki",
        "żbik",
        "pożar",
        "samowolny",
        "mięczak",
        "wimpy",
        "grymas twarzy",
        "czarownica",
        "czary",
        "wycofać",
        "uschnąć",
        "zwiędły",
        "Biada",
        "fatalny",
        "przygnębiający",
        "słowa",
        "robak",
        "używany",
        "zmartwiony",
        "martwić się",
        "frasobliwy",
        "gorzej",
        "pogorszenie",
        "Bezwartościowy",
        "rana",
        "spór",
        "gniew",
        "pomścić",
        "wrak",
        "zrujnowany",
        "klucz",
        "zapasy",
        "nieszczęśnik",
        "nędzny",
        "źle",
        "wykroczenie",
        "bezprawny",
        "niewłaściwie",
        "fasonowany",
        "skrzywiony",
        "ksenofobia",
        "ziewać",
        "ziewanie",
        "krzyk",
        "żółtaczka",
        "skowyt",
        "zamek błyskawiczny",
    ]
)

_ambivalent = set(
    [
        "obfitość",
        "uzbrojony",
        "balsam",
        "przechwałki",
        "porywisty",
        "mól książkowy",
        "bryknięcie",
        "sława",
        "oczarowany",
        "podstęp",
        "współudział",
        "wyznać",
        "przebiegły",
        "zależny",
        "różnorodny",
        "zdominować",
        "nieskończony",
        "egzekwować",
        "erotyczny",
        "ucieczka",
        "uczucie",
        "flirt",
        "grad",
        "hedonizm",
        "najwyższy",
        "pokorny",
        "natychmiast",
        "nieruchomy",
        "dochód",
        "infiltracja",
        "wpływ",
        "intensywny",
        "nie kończący się",
        "interwencja",
        "koronka",
        "liberał",
        "Lord",
        "macierzyński",
        "położna",
        "mama",
        "kubek",
        "rozgłos",
        "wszechmoc",
        "wybuch",
        "wybitny",
        "parada",
        "parafraza",
        "ropa naftowa",
        "prezentacja",
        "marnotrawny",
        "zacytować",
        "bredzić",
        "regresyjny",
        "ożywiać",
        "szczątki",
        "przejście na emeryturę",
        "wskrzesić",
        "rewolucja",
        "strach na wróble",
        "odosobnienie",
        "zmysłowy",
        "spektakl",
        "kręgosłup",
        "szterling",
        "soczysty",
        "zabobon",
        "zwierzchnictwo",
        "otaczać",
        "równoznaczny",
        "kuszące",
        "wiek dojrzewania",
        "leczyć",
        "nie pobity",
        "nieokiełznany",
        "niespodziewany",
        "niewyobrażalny",
        "rozwiązać",
        "pod górę",
        "głosować",
        "waga",
        "tęsknota",
    ]
)
